@@ -56,8 +56,10 @@ struct _ValaCCodeFunctionCallClass {
 };
 
 
+ValaCCodeFunctionCall* vala_ccode_function_call_construct (GType object_type, ValaCCodeExpression* call);
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call);
 void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr);
+void vala_ccode_function_call_insert_argument (ValaCCodeFunctionCall* self, gint index, ValaCCodeExpression* expr);
 GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self);
 ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* self);
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value);
