@@ -21,6 +21,8 @@
  */
 
 #include <ccode/valaccodeoncesection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodenode.h>
 
@@ -33,41 +35,33 @@ struct _ValaCCodeOnceSectionPrivate {
 
 #define VALA_CCODE_ONCE_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ONCE_SECTION, ValaCCodeOnceSectionPrivate))
 enum  {
-	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY,
-	VALA_CCODE_ONCE_SECTION_DEFINE
+	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY
 };
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_once_section_parent_class = NULL;
-static void vala_ccode_once_section_finalize (GObject * obj);
+static void vala_ccode_once_section_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeOnceSection* vala_ccode_once_section_construct (GType object_type, const char* def) {
+	ValaCCodeOnceSection* self;
+	g_return_val_if_fail (def != NULL, NULL);
+	self = (ValaCCodeOnceSection*) g_type_create_instance (object_type);
+	vala_ccode_once_section_set_define (self, def);
+	return self;
+}
+
+
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeOnceSection * self;
-	g_return_val_if_fail (def != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "define";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, def);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_ONCE_SECTION, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_once_section_construct (VALA_TYPE_CCODE_ONCE_SECTION, def);
 }
 
 
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = (ValaCCodeOnceSection*) base;
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#ifndef ");
 	vala_ccode_writer_write_string (writer, self->priv->_define);
@@ -76,18 +70,19 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	{
-		GeeList* node_collection;
-		int node_it;
-		node_collection = vala_ccode_fragment_get_children (VALA_CCODE_FRAGMENT (self));
-		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
+		GeeList* _tmp0;
+		GeeIterator* _tmp1;
+		GeeIterator* _node_it;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		_node_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_ccode_fragment_get_children ((ValaCCodeFragment*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_node_it)) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
-			{
-				vala_ccode_node_write_combined (node, writer);
-				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
-			}
+			node = (ValaCCodeNode*) gee_iterator_get (_node_it);
+			vala_ccode_node_write_combined (node, writer);
+			(node == NULL) ? NULL : (node = (vala_ccode_node_unref (node), NULL));
 		}
-		(node_collection == NULL ? NULL : (node_collection = (g_object_unref (node_collection), NULL)));
+		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
 	}
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#endif");
@@ -97,13 +92,13 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = (ValaCCodeOnceSection*) base;
+	g_return_if_fail (writer != NULL);
 }
 
 
 const char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_ONCE_SECTION (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_define;
 }
 
@@ -111,51 +106,19 @@ const char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self) {
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_ONCE_SECTION (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_define = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_define = (g_free (self->priv->_define), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "define");
-}
-
-
-static void vala_ccode_once_section_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (object);
-	switch (property_id) {
-		case VALA_CCODE_ONCE_SECTION_DEFINE:
-		g_value_set_string (value, vala_ccode_once_section_get_define (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_once_section_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (object);
-	switch (property_id) {
-		case VALA_CCODE_ONCE_SECTION_DEFINE:
-		vala_ccode_once_section_set_define (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_define = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_define = (g_free (self->priv->_define), NULL), _tmp2);
 }
 
 
 static void vala_ccode_once_section_class_init (ValaCCodeOnceSectionClass * klass) {
 	vala_ccode_once_section_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_once_section_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeOnceSectionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_once_section_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_once_section_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_once_section_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_once_section_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_once_section_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ONCE_SECTION_DEFINE, g_param_spec_string ("define", "define", "define", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -164,18 +127,18 @@ static void vala_ccode_once_section_instance_init (ValaCCodeOnceSection * self)
 }
 
 
-static void vala_ccode_once_section_finalize (GObject * obj) {
+static void vala_ccode_once_section_finalize (ValaCCodeNode* obj) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (obj);
 	self->priv->_define = (g_free (self->priv->_define), NULL);
-	G_OBJECT_CLASS (vala_ccode_once_section_parent_class)->finalize (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_once_section_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_once_section_get_type (void) {
 	static GType vala_ccode_once_section_type_id = 0;
 	if (vala_ccode_once_section_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_instance_init, NULL };
 		vala_ccode_once_section_type_id = g_type_register_static (VALA_TYPE_CCODE_FRAGMENT, "ValaCCodeOnceSection", &g_define_type_info, 0);
 	}
 	return vala_ccode_once_section_type_id;
