@@ -24,7 +24,10 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/collection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <ccode/valaccodevariabledeclarator.h>
+#include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodedeclarator.h>
 
 
@@ -37,21 +40,25 @@ struct _ValaCCodeStructPrivate {
 
 #define VALA_CCODE_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_STRUCT, ValaCCodeStructPrivate))
 enum  {
-	VALA_CCODE_STRUCT_DUMMY_PROPERTY,
-	VALA_CCODE_STRUCT_NAME
+	VALA_CCODE_STRUCT_DUMMY_PROPERTY
 };
 static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_struct_parent_class = NULL;
-static void vala_ccode_struct_finalize (GObject * obj);
+static void vala_ccode_struct_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeStruct* vala_ccode_struct_construct (GType object_type, const char* name) {
+	ValaCCodeStruct* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	self = (ValaCCodeStruct*) g_type_create_instance (object_type);
+	vala_ccode_struct_set_name (self, name);
+	return self;
+}
+
+
 ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
-	ValaCCodeStruct * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_STRUCT, 0, NULL);
-	vala_ccode_struct_set_name (self, name);
-	return self;
+	return vala_ccode_struct_construct (VALA_TYPE_CCODE_STRUCT, name);
 }
 
 
@@ -61,9 +68,9 @@ ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
  * @param decl a variable declaration
  */
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl) {
-	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
-	g_return_if_fail (VALA_IS_CCODE_DECLARATION (decl));
-	gee_collection_add (GEE_COLLECTION (self->priv->declarations), decl);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (decl != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->declarations, decl);
 }
 
 
@@ -76,37 +83,35 @@ void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclarat
 void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name, const char* name) {
 	ValaCCodeDeclaration* decl;
 	ValaCCodeVariableDeclarator* _tmp0;
-	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (type_name != NULL);
 	g_return_if_fail (name != NULL);
 	decl = vala_ccode_declaration_new (type_name);
 	_tmp0 = NULL;
-	vala_ccode_declaration_add_declarator (decl, VALA_CCODE_DECLARATOR ((_tmp0 = vala_ccode_variable_declarator_new (name))));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	vala_ccode_declaration_add_declarator (decl, (ValaCCodeDeclarator*) (_tmp0 = vala_ccode_variable_declarator_new (name, NULL)));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_ccode_node_unref (_tmp0), NULL));
 	vala_ccode_struct_add_declaration (self, decl);
-	(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
+	(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
 }
 
 
 static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeStruct * self;
-	self = VALA_CCODE_STRUCT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	self = (ValaCCodeStruct*) base;
+	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_string (writer, "struct ");
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_begin_block (writer);
 	{
-		GeeList* decl_collection;
-		int decl_it;
-		decl_collection = self->priv->declarations;
-		for (decl_it = 0; decl_it < gee_collection_get_size (GEE_COLLECTION (decl_collection)); decl_it = decl_it + 1) {
+		GeeIterator* _decl_it;
+		_decl_it = gee_iterable_iterator ((GeeIterable*) self->priv->declarations);
+		while (gee_iterator_next (_decl_it)) {
 			ValaCCodeDeclaration* decl;
-			decl = ((ValaCCodeDeclaration*) (gee_list_get (GEE_LIST (decl_collection), decl_it)));
-			{
-				vala_ccode_node_write_declaration (VALA_CCODE_NODE (decl), writer);
-				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
-			}
+			decl = (ValaCCodeDeclaration*) gee_iterator_get (_decl_it);
+			vala_ccode_node_write_declaration ((ValaCCodeNode*) decl, writer);
+			(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
 		}
+		(_decl_it == NULL) ? NULL : (_decl_it = (gee_collection_object_unref (_decl_it), NULL));
 	}
 	vala_ccode_writer_write_end_block (writer);
 	vala_ccode_writer_write_string (writer, ";");
@@ -116,7 +121,7 @@ static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 
 
 const char* vala_ccode_struct_get_name (ValaCCodeStruct* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_STRUCT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_name;
 }
 
@@ -124,72 +129,40 @@ const char* vala_ccode_struct_get_name (ValaCCodeStruct* self) {
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
-}
-
-
-static void vala_ccode_struct_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeStruct * self;
-	self = VALA_CCODE_STRUCT (object);
-	switch (property_id) {
-		case VALA_CCODE_STRUCT_NAME:
-		g_value_set_string (value, vala_ccode_struct_get_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_struct_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeStruct * self;
-	self = VALA_CCODE_STRUCT (object);
-	switch (property_id) {
-		case VALA_CCODE_STRUCT_NAME:
-		vala_ccode_struct_set_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
 }
 
 
 static void vala_ccode_struct_class_init (ValaCCodeStructClass * klass) {
 	vala_ccode_struct_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_struct_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeStructPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_struct_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_struct_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_struct_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_struct_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_STRUCT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_struct_instance_init (ValaCCodeStruct * self) {
 	self->priv = VALA_CCODE_STRUCT_GET_PRIVATE (self);
-	self->priv->declarations = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_DECLARATION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->declarations = (GeeList*) gee_array_list_new (VALA_TYPE_CCODE_DECLARATION, (GBoxedCopyFunc) vala_ccode_node_ref, vala_ccode_node_unref, g_direct_equal);
 }
 
 
-static void vala_ccode_struct_finalize (GObject * obj) {
+static void vala_ccode_struct_finalize (ValaCCodeNode* obj) {
 	ValaCCodeStruct * self;
 	self = VALA_CCODE_STRUCT (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->declarations == NULL ? NULL : (self->priv->declarations = (g_object_unref (self->priv->declarations), NULL)));
-	G_OBJECT_CLASS (vala_ccode_struct_parent_class)->finalize (obj);
+	(self->priv->declarations == NULL) ? NULL : (self->priv->declarations = (gee_collection_object_unref (self->priv->declarations), NULL));
+	VALA_CCODE_NODE_CLASS (vala_ccode_struct_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_struct_get_type (void) {
 	static GType vala_ccode_struct_type_id = 0;
 	if (vala_ccode_struct_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStruct), 0, (GInstanceInitFunc) vala_ccode_struct_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStructClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_struct_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStruct), 0, (GInstanceInitFunc) vala_ccode_struct_instance_init, NULL };
 		vala_ccode_struct_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeStruct", &g_define_type_info, 0);
 	}
 	return vala_ccode_struct_type_id;
