@@ -46,9 +46,8 @@ static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj);
 
 ValaCCodeWhileStatement* vala_ccode_while_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
 	ValaCCodeWhileStatement* self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
-	self = ((ValaCCodeWhileStatement*) (g_type_create_instance (object_type)));
+	g_return_val_if_fail (cond != NULL, NULL);
+	self = (ValaCCodeWhileStatement*) g_type_create_instance (object_type);
 	vala_ccode_while_statement_set_condition (self, cond);
 	vala_ccode_while_statement_set_body (self, stmt);
 	return self;
@@ -62,18 +61,18 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeWhileStatement * self;
-	self = VALA_CCODE_WHILE_STATEMENT (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
+	self = (ValaCCodeWhileStatement*) base;
+	g_return_if_fail (writer != NULL);
+	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
 	vala_ccode_writer_write_string (writer, "while (");
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
+	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_condition, writer);
 	vala_ccode_writer_write_string (writer, ")");
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
+	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_body, writer);
 }
 
 
 ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileStatement* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_condition;
 }
 
@@ -81,15 +80,15 @@ ValaCCodeExpression* vala_ccode_while_statement_get_condition (ValaCCodeWhileSta
 void vala_ccode_while_statement_set_condition (ValaCCodeWhileStatement* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp2);
 }
 
 
 ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_body;
 }
 
@@ -97,10 +96,10 @@ ValaCCodeStatement* vala_ccode_while_statement_get_body (ValaCCodeWhileStatement
 void vala_ccode_while_statement_set_body (ValaCCodeWhileStatement* self, ValaCCodeStatement* value) {
 	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_WHILE_STATEMENT (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL))), _tmp2);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp2);
 }
 
 
@@ -120,8 +119,8 @@ static void vala_ccode_while_statement_instance_init (ValaCCodeWhileStatement *
 static void vala_ccode_while_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)));
+	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
+	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL));
 	VALA_CCODE_NODE_CLASS (vala_ccode_while_statement_parent_class)->finalize (obj);
 }
 
