@@ -143,7 +143,7 @@ static GeeIterator* gee_array_list_real_iterator (GeeIterable* base) {
 static gboolean gee_array_list_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
 	self = (GeeArrayList*) base;
-	return (gee_list_index_of ((GeeList*) self, item) != (-1));
+	return gee_list_index_of ((GeeList*) self, item) != (-1);
 }
 
 
@@ -312,7 +312,7 @@ static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta) {
 	}
 	g_assert (_tmp0);
 	_vala_array_move (self->priv->_items, sizeof (gpointer), start, start + delta, self->priv->_size - start);
-	self->priv->_size = self->priv->_size + (delta);
+	self->priv->_size = self->priv->_size + delta;
 }
 
 
@@ -383,7 +383,7 @@ static gboolean gee_array_list_iterator_real_next (GeeIterator* base) {
 	if (self->priv->_index < self->priv->_list->priv->_size) {
 		self->priv->_index++;
 	}
-	return (self->priv->_index < self->priv->_list->priv->_size);
+	return self->priv->_index < self->priv->_list->priv->_size;
 }
 
 
