@@ -323,14 +323,14 @@ static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointe
 			} else {
 				_tmp1 = !self->priv->_key_equal_func ((*node)->key, key);
 			}
-			_tmp0 = (_tmp1);
+			_tmp0 = _tmp1;
 		} else {
 			_tmp0 = FALSE;
 		}
 		if (!_tmp0) {
 			break;
 		}
-		node = &((*node)->next);
+		node = &(*node)->next;
 	}
 	return node;
 }
@@ -341,7 +341,7 @@ static gboolean gee_hash_map_real_contains (GeeMap* base, gconstpointer key) {
 	GeeHashMapNode** node;
 	self = (GeeHashMap*) base;
 	node = gee_hash_map_lookup_node (self, key);
-	return ((*node) != NULL);
+	return (*node) != NULL;
 }
 
 
@@ -349,7 +349,7 @@ static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
 	GeeHashMapNode* node;
 	self = (GeeHashMap*) base;
-	node = (*gee_hash_map_lookup_node (self, key));
+	node = *gee_hash_map_lookup_node (self, key);
 	if (node != NULL) {
 		gconstpointer _tmp0;
 		_tmp0 = NULL;
@@ -456,7 +456,7 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 	} else {
 		_tmp1 = FALSE;
 	}
-	if ((_tmp1)) {
+	if (_tmp1) {
 		_tmp0 = TRUE;
 	} else {
 		gboolean _tmp2;
@@ -466,7 +466,7 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		} else {
 			_tmp2 = FALSE;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	}
 	if (_tmp0) {
 		gint new_array_size;
@@ -755,7 +755,7 @@ static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
-	return (self->priv->_node != NULL);
+	return self->priv->_node != NULL;
 }
 
 
@@ -1003,7 +1003,7 @@ static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base) {
 		self->priv->_index++;
 		self->priv->_node = self->priv->_map->priv->_nodes[self->priv->_index];
 	}
-	return (self->priv->_node != NULL);
+	return self->priv->_node != NULL;
 }
 
 
