@@ -89,8 +89,7 @@ static void gee_read_only_set_finalize (GeeCollectionObject* obj);
 
 GeeReadOnlySet* gee_read_only_set_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
 	GeeReadOnlySet* self;
-	g_return_val_if_fail (set == NULL || GEE_IS_SET (set), NULL);
-	self = ((GeeReadOnlySet*) (g_type_create_instance (object_type)));
+	self = (GeeReadOnlySet*) g_type_create_instance (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -106,86 +105,86 @@ GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func,
 
 static GType gee_read_only_set_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	if (self->priv->_set == NULL) {
-		return GEE_ITERATOR (gee_read_only_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
+		return (GeeIterator*) gee_read_only_set_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
 	}
-	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_set));
+	return gee_iterable_iterator ((GeeIterable*) self->priv->_set);
 }
 
 
 static gboolean gee_read_only_set_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	if (self->priv->_set == NULL) {
 		return FALSE;
 	}
-	return gee_collection_contains (GEE_COLLECTION (self->priv->_set), item);
+	return gee_collection_contains ((GeeCollection*) self->priv->_set, item);
 }
 
 
 static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_read_only_set_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_set_real_clear (GeeCollection* base) {
 	GeeReadOnlySet * self;
-	self = GEE_READ_ONLY_SET (base);
+	self = (GeeReadOnlySet*) base;
 	g_assert_not_reached ();
 }
 
 
 static gint gee_read_only_set_real_get_size (GeeCollection* base) {
 	GeeReadOnlySet* self;
-	self = GEE_READ_ONLY_SET (base);
-	return gee_collection_get_size (GEE_COLLECTION (self->priv->_set));
+	self = (GeeReadOnlySet*) base;
+	return gee_collection_get_size ((GeeCollection*) self->priv->_set);
 }
 
 
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value) {
 	GeeSet* _tmp1;
 	GeeSet* _tmp0;
-	g_return_if_fail (GEE_IS_READ_ONLY_SET (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL))), _tmp1);
+	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)), _tmp1);
 }
 
 
 static gboolean gee_read_only_set_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlySetIterator * self;
-	self = GEE_READ_ONLY_SET_ITERATOR (base);
+	self = (GeeReadOnlySetIterator*) base;
 	return FALSE;
 }
 
 
 static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlySetIterator * self;
-	self = GEE_READ_ONLY_SET_ITERATOR (base);
+	self = (GeeReadOnlySetIterator*) base;
 	return NULL;
 }
 
 
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
 	GeeReadOnlySetIterator* self;
-	self = ((GeeReadOnlySetIterator*) (g_type_create_instance (object_type)));
+	self = (GeeReadOnlySetIterator*) g_type_create_instance (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -265,7 +264,7 @@ static void gee_read_only_set_instance_init (GeeReadOnlySet * self) {
 static void gee_read_only_set_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (obj);
-	(self->priv->_set == NULL ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL)));
+	(self->priv->_set == NULL) ? NULL : (self->priv->_set = (gee_collection_object_unref (self->priv->_set), NULL));
 	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_set_parent_class)->finalize (obj);
 }
 
