@@ -1,6 +1,7 @@
 /* valaccodearraymodule.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2009  Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,15 +27,18 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <vala/valaformalparameter.h>
+#include <gee/map.h>
 #include <vala/valaelementaccess.h>
+#include <vala/valaassignment.h>
 #include <ccode/valaccodeexpression.h>
-#include <vala/valadatatype.h>
-#include <vala/valasourcereference.h>
+#include <vala/valaexpression.h>
 #include <stdlib.h>
 #include <string.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valamethodcall.h>
 #include <vala/valaarraycreationexpression.h>
-#include <vala/valaexpression.h>
 #include <gobject/valaccodemethodcallmodule.h>
 #include <gobject/valaccodegenerator.h>
 #include <gobject/valaccodemodule.h>
@@ -53,9 +57,6 @@ typedef struct _ValaCCodeArrayModule ValaCCodeArrayModule;
 typedef struct _ValaCCodeArrayModuleClass ValaCCodeArrayModuleClass;
 typedef struct _ValaCCodeArrayModulePrivate ValaCCodeArrayModulePrivate;
 
-/**
- * The link between an assignment and generated code.
- */
 struct _ValaCCodeArrayModule {
 	ValaCCodeMethodCallModule parent_instance;
 	ValaCCodeArrayModulePrivate * priv;
