@@ -50,6 +50,7 @@ enum  {
 static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
+static char* vala_class_register_function_real_get_class_finalize_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base);
@@ -134,6 +135,21 @@ static char* vala_class_register_function_real_get_base_init_func_name (ValaType
 }
 
 
+static char* vala_class_register_function_real_get_class_finalize_func_name (ValaTypeRegisterFunction* base) {
+	ValaClassRegisterFunction * self;
+	self = (ValaClassRegisterFunction*) base;
+	if (vala_class_get_static_destructor (self->priv->_class_reference) != NULL) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_class_finalize", _tmp0 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	} else {
+		return g_strdup ("NULL");
+	}
+}
+
+
 static char* vala_class_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	gboolean _tmp0;
@@ -378,7 +394,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 			char* _tmp6;
 			char* _tmp5;
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
-			if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
+			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
 				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 				continue;
 			}
@@ -394,7 +410,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 			_tmp7 = NULL;
 			_tmp6 = NULL;
 			_tmp5 = NULL;
-			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp9 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, (ValaCCodeExpression*) (_tmp8 = vala_ccode_constant_new (_tmp7 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp5 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp6 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))))));
+			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp9 = vala_ccode_variable_declarator_new (iface_info_name, (ValaCCodeExpression*) (_tmp8 = vala_ccode_constant_new (_tmp7 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp5 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp6 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))))));
 			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
 			(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
 			_tmp7 = (g_free (_tmp7), NULL);
@@ -443,7 +459,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 			char* _tmp12;
 			ValaCCodeExpressionStatement* _tmp14;
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
-			if (!(VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type)))) {
+			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
 				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 				continue;
 			}
@@ -505,6 +521,7 @@ static void vala_class_register_function_class_init (ValaClassRegisterFunctionCl
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_class_register_function_real_get_type_declaration;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_class_register_function_real_get_type_struct_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_class_register_function_real_get_base_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_class_finalize_func_name = vala_class_register_function_real_get_class_finalize_func_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_finalize_func_name = vala_class_register_function_real_get_base_finalize_func_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_class_register_function_real_get_class_init_func_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_class_register_function_real_get_instance_struct_size;
