@@ -1,6 +1,6 @@
 /* valacodenode.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,9 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <ccode/valaccodenode.h>
-#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -36,178 +37,182 @@ typedef struct _ValaAddressofExpression ValaAddressofExpression;
 typedef struct _ValaAddressofExpressionClass ValaAddressofExpressionClass;
 typedef struct _ValaExpression ValaExpression;
 typedef struct _ValaExpressionClass ValaExpressionClass;
+typedef struct _ValaDataType ValaDataType;
+typedef struct _ValaDataTypeClass ValaDataTypeClass;
 typedef struct _ValaCodeNode ValaCodeNode;
 typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
-typedef struct _ValaCodeVisitor ValaCodeVisitor;
-typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
+typedef struct _ValaReport ValaReport;
+typedef struct _ValaReportClass ValaReportClass;
+typedef struct _ValaNamespace ValaNamespace;
+typedef struct _ValaNamespaceClass ValaNamespaceClass;
 typedef struct _ValaSymbol ValaSymbol;
 typedef struct _ValaSymbolClass ValaSymbolClass;
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
-typedef struct _ValaMethod ValaMethod;
-typedef struct _ValaMethodClass ValaMethodClass;
-typedef struct _ValaMember ValaMember;
-typedef struct _ValaMemberClass ValaMemberClass;
-typedef struct _ValaDataType ValaDataType;
-typedef struct _ValaDataTypeClass ValaDataTypeClass;
+typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
+typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;
+typedef struct _ValaCodeVisitor ValaCodeVisitor;
+typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
 typedef struct _ValaTypeParameter ValaTypeParameter;
 typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
-typedef struct _ValaSourceReference ValaSourceReference;
-typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
-typedef struct _ValaFormalParameter ValaFormalParameter;
-typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
-typedef struct _ValaCodeGenerator ValaCodeGenerator;
-typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
-typedef struct _ValaNamespace ValaNamespace;
-typedef struct _ValaNamespaceClass ValaNamespaceClass;
-typedef struct _ValaClass ValaClass;
-typedef struct _ValaClassClass ValaClassClass;
-typedef struct _ValaConstant ValaConstant;
-typedef struct _ValaConstantClass ValaConstantClass;
+typedef struct _ValaTypeSymbol ValaTypeSymbol;
+typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
 typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
-typedef struct _ValaProperty ValaProperty;
-typedef struct _ValaPropertyClass ValaPropertyClass;
-typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
-typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
+typedef struct _ValaStringLiteral ValaStringLiteral;
+typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
+typedef struct _ValaLiteral ValaLiteral;
+typedef struct _ValaLiteralClass ValaLiteralClass;
+typedef struct _ValaConstant ValaConstant;
+typedef struct _ValaConstantClass ValaConstantClass;
+typedef struct _ValaCreationMethod ValaCreationMethod;
+typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+typedef struct _ValaFormalParameter ValaFormalParameter;
+typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
+typedef struct _ValaLocalVariable ValaLocalVariable;
+typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
 typedef struct _ValaStatement ValaStatement;
 typedef struct _ValaStatementIface ValaStatementIface;
-typedef struct _ValaLocalVariable ValaLocalVariable;
-typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
 typedef struct _ValaBasicBlock ValaBasicBlock;
 typedef struct _ValaBasicBlockClass ValaBasicBlockClass;
-typedef struct _ValaSignal ValaSignal;
-typedef struct _ValaSignalClass ValaSignalClass;
-typedef struct _ValaDelegate ValaDelegate;
-typedef struct _ValaDelegateClass ValaDelegateClass;
-typedef struct _ValaStruct ValaStruct;
-typedef struct _ValaStructClass ValaStructClass;
-typedef struct _ValaEnum ValaEnum;
-typedef struct _ValaEnumClass ValaEnumClass;
+typedef struct _ValaBooleanLiteral ValaBooleanLiteral;
+typedef struct _ValaBooleanLiteralClass ValaBooleanLiteralClass;
+typedef struct _ValaRealLiteral ValaRealLiteral;
+typedef struct _ValaRealLiteralClass ValaRealLiteralClass;
+typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
+typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;
 typedef struct _ValaEnumValue ValaEnumValue;
 typedef struct _ValaEnumValueClass ValaEnumValueClass;
+typedef struct _ValaMemberAccess ValaMemberAccess;
+typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
+typedef struct _ValaDelegate ValaDelegate;
+typedef struct _ValaDelegateClass ValaDelegateClass;
+typedef struct _ValaNullLiteral ValaNullLiteral;
+typedef struct _ValaNullLiteralClass ValaNullLiteralClass;
+typedef struct _ValaSignal ValaSignal;
+typedef struct _ValaSignalClass ValaSignalClass;
+typedef struct _ValaInterface ValaInterface;
+typedef struct _ValaInterfaceClass ValaInterfaceClass;
+typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
+typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
+typedef struct _ValaProperty ValaProperty;
+typedef struct _ValaPropertyClass ValaPropertyClass;
+typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
+typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
 typedef struct _ValaConstructor ValaConstructor;
 typedef struct _ValaConstructorClass ValaConstructorClass;
 typedef struct _ValaDestructor ValaDestructor;
 typedef struct _ValaDestructorClass ValaDestructorClass;
-typedef struct _ValaInterface ValaInterface;
-typedef struct _ValaInterfaceClass ValaInterfaceClass;
-typedef struct _ValaErrorDomain ValaErrorDomain;
-typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
+typedef struct _ValaStruct ValaStruct;
+typedef struct _ValaStructClass ValaStructClass;
+typedef struct _ValaEnum ValaEnum;
+typedef struct _ValaEnumClass ValaEnumClass;
 typedef struct _ValaErrorCode ValaErrorCode;
 typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
-typedef struct _ValaDynamicMethod ValaDynamicMethod;
-typedef struct _ValaDynamicMethodClass ValaDynamicMethodClass;
-typedef struct _ValaInvocationExpression ValaInvocationExpression;
-typedef struct _ValaInvocationExpressionClass ValaInvocationExpressionClass;
-typedef struct _ValaCreationMethod ValaCreationMethod;
-typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
-typedef struct _ValaDynamicSignal ValaDynamicSignal;
-typedef struct _ValaDynamicSignalClass ValaDynamicSignalClass;
-typedef struct _ValaEmptyStatement ValaEmptyStatement;
-typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;
-typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
-typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;
-typedef struct _ValaInitializerList ValaInitializerList;
-typedef struct _ValaInitializerListClass ValaInitializerListClass;
-typedef struct _ValaExpressionStatement ValaExpressionStatement;
-typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;
-typedef struct _ValaIfStatement ValaIfStatement;
-typedef struct _ValaIfStatementClass ValaIfStatementClass;
-typedef struct _ValaSwitchStatement ValaSwitchStatement;
-typedef struct _ValaSwitchStatementClass ValaSwitchStatementClass;
-typedef struct _ValaSwitchSection ValaSwitchSection;
-typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
-typedef struct _ValaSwitchLabel ValaSwitchLabel;
-typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
-typedef struct _ValaWhileStatement ValaWhileStatement;
-typedef struct _ValaWhileStatementClass ValaWhileStatementClass;
-typedef struct _ValaDoStatement ValaDoStatement;
-typedef struct _ValaDoStatementClass ValaDoStatementClass;
-typedef struct _ValaForStatement ValaForStatement;
-typedef struct _ValaForStatementClass ValaForStatementClass;
-typedef struct _ValaForeachStatement ValaForeachStatement;
-typedef struct _ValaForeachStatementClass ValaForeachStatementClass;
-typedef struct _ValaBreakStatement ValaBreakStatement;
-typedef struct _ValaBreakStatementClass ValaBreakStatementClass;
-typedef struct _ValaContinueStatement ValaContinueStatement;
-typedef struct _ValaContinueStatementClass ValaContinueStatementClass;
+typedef struct _ValaErrorDomain ValaErrorDomain;
+typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
 typedef struct _ValaReturnStatement ValaReturnStatement;
 typedef struct _ValaReturnStatementClass ValaReturnStatementClass;
-typedef struct _ValaThrowStatement ValaThrowStatement;
-typedef struct _ValaThrowStatementClass ValaThrowStatementClass;
-typedef struct _ValaTryStatement ValaTryStatement;
-typedef struct _ValaTryStatementClass ValaTryStatementClass;
-typedef struct _ValaCatchClause ValaCatchClause;
-typedef struct _ValaCatchClauseClass ValaCatchClauseClass;
-typedef struct _ValaLockStatement ValaLockStatement;
-typedef struct _ValaLockStatementClass ValaLockStatementClass;
-typedef struct _ValaDeleteStatement ValaDeleteStatement;
-typedef struct _ValaDeleteStatementClass ValaDeleteStatementClass;
-typedef struct _ValaArrayCreationExpression ValaArrayCreationExpression;
-typedef struct _ValaArrayCreationExpressionClass ValaArrayCreationExpressionClass;
-typedef struct _ValaBooleanLiteral ValaBooleanLiteral;
-typedef struct _ValaBooleanLiteralClass ValaBooleanLiteralClass;
-typedef struct _ValaLiteral ValaLiteral;
-typedef struct _ValaLiteralClass ValaLiteralClass;
-typedef struct _ValaCharacterLiteral ValaCharacterLiteral;
-typedef struct _ValaCharacterLiteralClass ValaCharacterLiteralClass;
-typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
-typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;
-typedef struct _ValaRealLiteral ValaRealLiteral;
-typedef struct _ValaRealLiteralClass ValaRealLiteralClass;
-typedef struct _ValaStringLiteral ValaStringLiteral;
-typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
-typedef struct _ValaNullLiteral ValaNullLiteral;
-typedef struct _ValaNullLiteralClass ValaNullLiteralClass;
-typedef struct _ValaParenthesizedExpression ValaParenthesizedExpression;
-typedef struct _ValaParenthesizedExpressionClass ValaParenthesizedExpressionClass;
-typedef struct _ValaMemberAccess ValaMemberAccess;
-typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
+typedef struct _ValaAssignment ValaAssignment;
+typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaElementAccess ValaElementAccess;
 typedef struct _ValaElementAccessClass ValaElementAccessClass;
-typedef struct _ValaBaseAccess ValaBaseAccess;
-typedef struct _ValaBaseAccessClass ValaBaseAccessClass;
-typedef struct _ValaPostfixExpression ValaPostfixExpression;
-typedef struct _ValaPostfixExpressionClass ValaPostfixExpressionClass;
+typedef struct _ValaMethodCall ValaMethodCall;
+typedef struct _ValaMethodCallClass ValaMethodCallClass;
 typedef struct _ValaObjectCreationExpression ValaObjectCreationExpression;
 typedef struct _ValaObjectCreationExpressionClass ValaObjectCreationExpressionClass;
 typedef struct _ValaMemberInitializer ValaMemberInitializer;
 typedef struct _ValaMemberInitializerClass ValaMemberInitializerClass;
+typedef struct _ValaUsingDirective ValaUsingDirective;
+typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
+typedef struct _ValaPointerIndirection ValaPointerIndirection;
+typedef struct _ValaPointerIndirectionClass ValaPointerIndirectionClass;
+typedef struct _ValaBaseAccess ValaBaseAccess;
+typedef struct _ValaBaseAccessClass ValaBaseAccessClass;
+typedef struct _ValaExpressionStatement ValaExpressionStatement;
+typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;
+typedef struct _ValaUnaryExpression ValaUnaryExpression;
+typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;
+typedef struct _ValaBinaryExpression ValaBinaryExpression;
+typedef struct _ValaBinaryExpressionClass ValaBinaryExpressionClass;
+typedef struct _ValaWhileStatement ValaWhileStatement;
+typedef struct _ValaWhileStatementClass ValaWhileStatementClass;
+typedef struct _ValaBreakStatement ValaBreakStatement;
+typedef struct _ValaBreakStatementClass ValaBreakStatementClass;
+typedef struct _ValaIfStatement ValaIfStatement;
+typedef struct _ValaIfStatementClass ValaIfStatementClass;
+typedef struct _ValaDoStatement ValaDoStatement;
+typedef struct _ValaDoStatementClass ValaDoStatementClass;
+typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
+typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;
+typedef struct _ValaForStatement ValaForStatement;
+typedef struct _ValaForStatementClass ValaForStatementClass;
+typedef struct _ValaYieldStatement ValaYieldStatement;
+typedef struct _ValaYieldStatementClass ValaYieldStatementClass;
+typedef struct _ValaLambdaExpression ValaLambdaExpression;
+typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
+typedef struct _ValaEmptyStatement ValaEmptyStatement;
+typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;
+typedef struct _ValaArrayCreationExpression ValaArrayCreationExpression;
+typedef struct _ValaArrayCreationExpressionClass ValaArrayCreationExpressionClass;
+typedef struct _ValaInitializerList ValaInitializerList;
+typedef struct _ValaInitializerListClass ValaInitializerListClass;
+typedef struct _ValaSwitchLabel ValaSwitchLabel;
+typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
+typedef struct _ValaSwitchSection ValaSwitchSection;
+typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
+typedef struct _ValaSwitchStatement ValaSwitchStatement;
+typedef struct _ValaSwitchStatementClass ValaSwitchStatementClass;
+typedef struct _ValaForeachStatement ValaForeachStatement;
+typedef struct _ValaForeachStatementClass ValaForeachStatementClass;
+typedef struct _ValaContinueStatement ValaContinueStatement;
+typedef struct _ValaContinueStatementClass ValaContinueStatementClass;
+typedef struct _ValaThrowStatement ValaThrowStatement;
+typedef struct _ValaThrowStatementClass ValaThrowStatementClass;
+typedef struct _ValaCatchClause ValaCatchClause;
+typedef struct _ValaCatchClauseClass ValaCatchClauseClass;
+typedef struct _ValaTryStatement ValaTryStatement;
+typedef struct _ValaTryStatementClass ValaTryStatementClass;
+typedef struct _ValaLockStatement ValaLockStatement;
+typedef struct _ValaLockStatementClass ValaLockStatementClass;
+typedef struct _ValaDeleteStatement ValaDeleteStatement;
+typedef struct _ValaDeleteStatementClass ValaDeleteStatementClass;
+typedef struct _ValaCharacterLiteral ValaCharacterLiteral;
+typedef struct _ValaCharacterLiteralClass ValaCharacterLiteralClass;
+typedef struct _ValaPostfixExpression ValaPostfixExpression;
+typedef struct _ValaPostfixExpressionClass ValaPostfixExpressionClass;
 typedef struct _ValaSizeofExpression ValaSizeofExpression;
 typedef struct _ValaSizeofExpressionClass ValaSizeofExpressionClass;
 typedef struct _ValaTypeofExpression ValaTypeofExpression;
 typedef struct _ValaTypeofExpressionClass ValaTypeofExpressionClass;
-typedef struct _ValaUnaryExpression ValaUnaryExpression;
-typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;
 typedef struct _ValaCastExpression ValaCastExpression;
 typedef struct _ValaCastExpressionClass ValaCastExpressionClass;
-typedef struct _ValaPointerIndirection ValaPointerIndirection;
-typedef struct _ValaPointerIndirectionClass ValaPointerIndirectionClass;
 typedef struct _ValaReferenceTransferExpression ValaReferenceTransferExpression;
 typedef struct _ValaReferenceTransferExpressionClass ValaReferenceTransferExpressionClass;
-typedef struct _ValaBinaryExpression ValaBinaryExpression;
-typedef struct _ValaBinaryExpressionClass ValaBinaryExpressionClass;
 typedef struct _ValaTypeCheck ValaTypeCheck;
 typedef struct _ValaTypeCheckClass ValaTypeCheckClass;
 typedef struct _ValaConditionalExpression ValaConditionalExpression;
 typedef struct _ValaConditionalExpressionClass ValaConditionalExpressionClass;
-typedef struct _ValaLambdaExpression ValaLambdaExpression;
-typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
-typedef struct _ValaAssignment ValaAssignment;
-typedef struct _ValaAssignmentClass ValaAssignmentClass;
-typedef struct _ValaNamespaceReference ValaNamespaceReference;
-typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
+typedef struct _ValaGenericType ValaGenericType;
+typedef struct _ValaGenericTypeClass ValaGenericTypeClass;
+typedef struct _ValaCodeGenerator ValaCodeGenerator;
+typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
 typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
 typedef struct _ValaSourceFileCycleClass ValaSourceFileCycleClass;
-typedef struct _ValaNamedArgument ValaNamedArgument;
-typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;
 typedef struct _ValaAttribute ValaAttribute;
 typedef struct _ValaAttributeClass ValaAttributeClass;
 
@@ -219,6 +224,7 @@ typedef struct _ValaAttributeClass ValaAttributeClass;
 #define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
 
 typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
+typedef struct _ValaParamSpecCodeNode ValaParamSpecCodeNode;
 
 /**
  * Represents a part of the parsed source code.
@@ -227,42 +233,61 @@ typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
  * compilation process.
  */
 struct _ValaCodeNode {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeNodePrivate * priv;
 	GList* attributes;
 };
 
 struct _ValaCodeNodeClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeNode *self);
 	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
 	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
+	gboolean (*check) (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 	char* (*to_string) (ValaCodeNode* self);
-	ValaCodeBinding* (*create_code_binding) (ValaCodeNode* self, ValaCodeGenerator* codegen);
+	void (*get_defined_variables) (ValaCodeNode* self, GeeCollection* collection);
+	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
+};
+
+struct _ValaParamSpecCodeNode {
+	GParamSpec parent_instance;
 };
 
 
+GeeList* vala_code_node_get_error_types (ValaCodeNode* self);
+void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
+void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
+gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name);
 char* vala_code_node_to_string (ValaCodeNode* self);
-ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
-ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
-ValaCodeNode* vala_code_node_new (void);
+void vala_code_node_get_defined_variables (ValaCodeNode* self, GeeCollection* collection);
+void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
+char* vala_code_node_get_temp_name (ValaCodeNode* self);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
+const char* vala_code_node_get_type_name (ValaCodeNode* self);
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
+gboolean vala_code_node_get_checked (ValaCodeNode* self);
+void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
-void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value);
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_node (const GValue* value);
+void vala_value_set_code_node (GValue* value, gpointer v_object);
 GType vala_code_node_get_type (void);
+gpointer vala_code_node_ref (gpointer instance);
+void vala_code_node_unref (gpointer instance);
 
 
 G_END_DECLS
