@@ -29,8 +29,10 @@
 #include <string.h>
 #include <gee/list.h>
 #include <vala/valamethod.h>
-#include <vala/valacodenode.h>
-#include <vala/valacodebinding.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valamethodcall.h>
 
 G_BEGIN_DECLS
 
@@ -42,6 +44,8 @@ G_BEGIN_DECLS
 #define VALA_IS_DYNAMIC_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DYNAMIC_METHOD))
 #define VALA_DYNAMIC_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DYNAMIC_METHOD, ValaDynamicMethodClass))
 
+typedef struct _ValaDynamicMethod ValaDynamicMethod;
+typedef struct _ValaDynamicMethodClass ValaDynamicMethodClass;
 typedef struct _ValaDynamicMethodPrivate ValaDynamicMethodPrivate;
 
 /**
@@ -61,8 +65,8 @@ ValaDynamicMethod* vala_dynamic_method_construct (GType object_type, ValaDataTyp
 ValaDynamicMethod* vala_dynamic_method_new (ValaDataType* dynamic_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 ValaDataType* vala_dynamic_method_get_dynamic_type (ValaDynamicMethod* self);
 void vala_dynamic_method_set_dynamic_type (ValaDynamicMethod* self, ValaDataType* value);
-ValaInvocationExpression* vala_dynamic_method_get_invocation (ValaDynamicMethod* self);
-void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaInvocationExpression* value);
+ValaMethodCall* vala_dynamic_method_get_invocation (ValaDynamicMethod* self);
+void vala_dynamic_method_set_invocation (ValaDynamicMethod* self, ValaMethodCall* value);
 GType vala_dynamic_method_get_type (void);
 
 
