@@ -63,6 +63,8 @@ void vala_field_set_cname (ValaField* self, const char* cname);
 char* vala_field_get_default_cname (ValaField* self);
 char* vala_field_get_array_length_cname (ValaField* self);
 void vala_field_set_array_length_cname (ValaField* self, const char* array_length_cname);
+char* vala_field_get_array_length_cexpr (ValaField* self);
+void vala_field_set_array_length_cexpr (ValaField* self, const char* array_length_cexpr);
 void vala_field_process_attributes (ValaField* self);
 char* vala_field_get_ctype (ValaField* self);
 void vala_field_set_ctype (ValaField* self, const char* ctype);
@@ -79,6 +81,7 @@ void vala_field_set_no_array_length (ValaField* self, gboolean value);
 gboolean vala_field_get_array_null_terminated (ValaField* self);
 void vala_field_set_array_null_terminated (ValaField* self, gboolean value);
 gboolean vala_field_get_has_array_length_cname (ValaField* self);
+gboolean vala_field_get_has_array_length_cexpr (ValaField* self);
 GType vala_field_get_type (void);
 
 
