@@ -24,6 +24,7 @@
 #include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <vala/valacodenode.h>
+#include <vala/valatypesymbol.h>
 
 
 
@@ -70,20 +71,20 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* arg_it;
+		GeeIterator* _arg_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (arg_it)) {
+		_arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_arg_it)) {
 			ValaDataType* arg;
 			ValaDataType* _tmp2;
-			arg = (ValaDataType*) gee_iterator_get (arg_it);
+			arg = (ValaDataType*) gee_iterator_get (_arg_it);
 			_tmp2 = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp2 = vala_data_type_copy (arg));
 			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
 	return (ValaDataType*) result;
 }
