@@ -56,9 +56,8 @@ static void vala_lockable_base_init (ValaLockableIface * iface) {
 GType vala_lockable_get_type (void) {
 	static GType vala_lockable_type_id = 0;
 	if (vala_lockable_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaLockableIface), (GBaseInitFunc) vala_lockable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaLockableIface), (GBaseInitFunc) vala_lockable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
 		vala_lockable_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaLockable", &g_define_type_info, 0);
-		g_type_interface_add_prerequisite (vala_lockable_type_id, G_TYPE_OBJECT);
 	}
 	return vala_lockable_type_id;
 }
