@@ -1,6 +1,6 @@
 /* valaobjectcreationexpression.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,11 +42,12 @@
 #include <vala/valaobjecttype.h>
 #include <vala/valaobjecttypesymbol.h>
 #include <vala/valastruct.h>
-#include <vala/valavaluetype.h>
+#include <vala/valastructvaluetype.h>
 #include <vala/valaerrorcode.h>
 #include <vala/valaerrortype.h>
 #include <vala/valaerrordomain.h>
 #include <vala/valasourcefile.h>
+#include <vala/valacodecontext.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valamethodtype.h>
 
@@ -170,26 +171,26 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 		vala_code_node_accept ((ValaCodeNode*) self->priv->_member_name, visitor);
 	}
 	{
-		GeeIterator* arg_it;
-		arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
-		while (gee_iterator_next (arg_it)) {
+		GeeIterator* _arg_it;
+		_arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
+		while (gee_iterator_next (_arg_it)) {
 			ValaExpression* arg;
-			arg = (ValaExpression*) gee_iterator_get (arg_it);
+			arg = (ValaExpression*) gee_iterator_get (_arg_it);
 			vala_code_node_accept ((ValaCodeNode*) arg, visitor);
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
 	{
-		GeeIterator* init_it;
-		init_it = gee_iterable_iterator ((GeeIterable*) self->priv->object_initializer);
-		while (gee_iterator_next (init_it)) {
+		GeeIterator* _init_it;
+		_init_it = gee_iterable_iterator ((GeeIterable*) self->priv->object_initializer);
+		while (gee_iterator_next (_init_it)) {
 			ValaMemberInitializer* init;
-			init = (ValaMemberInitializer*) gee_iterator_get (init_it);
+			init = (ValaMemberInitializer*) gee_iterator_get (_init_it);
 			vala_code_node_accept ((ValaCodeNode*) init, visitor);
 			(init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL));
 		}
-		(init_it == NULL) ? NULL : (init_it = (gee_collection_object_unref (init_it), NULL));
+		(_init_it == NULL) ? NULL : (_init_it = (gee_collection_object_unref (_init_it), NULL));
 	}
 }
 
@@ -209,7 +210,7 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 		_tmp0 = FALSE;
 	}
 	if (_tmp0) {
-		gee_list_set ((GeeList*) self->priv->argument_list, index, new_node);
+		gee_list_set (self->priv->argument_list, index, new_node);
 		vala_code_node_set_parent_node ((ValaCodeNode*) new_node, (ValaCodeNode*) self);
 	}
 }
@@ -241,8 +242,8 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 	gint _tmp28;
 	gint given_num_type_args;
 	gint expected_num_type_args;
-	gboolean _tmp41;
-	gboolean _tmp60;
+	gboolean _tmp44;
+	gboolean _tmp64;
 	self = (ValaObjectCreationExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -288,7 +289,7 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 			type_sym = (_tmp6 = (_tmp5 = vala_symbol_get_parent_symbol (constructor_sym), (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5)), (type_sym == NULL) ? NULL : (type_sym = (vala_code_node_unref (type_sym), NULL)), _tmp6);
 			_tmp7 = NULL;
 			constructor = (_tmp7 = VALA_METHOD (constructor_sym), (_tmp7 == NULL) ? NULL : vala_code_node_ref (_tmp7));
-			if (!(VALA_IS_CREATION_METHOD (constructor_sym))) {
+			if (!VALA_IS_CREATION_METHOD (constructor_sym)) {
 				char* _tmp9;
 				char* _tmp8;
 				gboolean _tmp10;
@@ -327,12 +328,12 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 			if (VALA_IS_STRUCT (type_sym)) {
 				ValaTypeSymbol* _tmp18;
 				ValaTypeSymbol* _tmp17;
-				ValaValueType* _tmp19;
+				ValaStructValueType* _tmp19;
 				_tmp18 = NULL;
 				_tmp17 = NULL;
 				type = (_tmp18 = (_tmp17 = VALA_TYPESYMBOL (type_sym), (_tmp17 == NULL) ? NULL : vala_code_node_ref (_tmp17)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp18);
 				_tmp19 = NULL;
-				vala_object_creation_expression_set_type_reference (self, (ValaDataType*) (_tmp19 = vala_value_type_new (type)));
+				vala_object_creation_expression_set_type_reference (self, (ValaDataType*) (_tmp19 = vala_struct_value_type_new (VALA_STRUCT (type))));
 				(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_code_node_unref (_tmp19), NULL));
 			} else {
 				if (VALA_IS_ERROR_CODE (type_sym)) {
@@ -356,16 +357,16 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 			}
 		}
 		{
-			GeeIterator* type_arg_it;
-			type_arg_it = gee_iterable_iterator ((GeeIterable*) type_args);
-			while (gee_iterator_next (type_arg_it)) {
+			GeeIterator* _type_arg_it;
+			_type_arg_it = gee_iterable_iterator ((GeeIterable*) type_args);
+			while (gee_iterator_next (_type_arg_it)) {
 				ValaDataType* type_arg;
-				type_arg = (ValaDataType*) gee_iterator_get (type_arg_it);
+				type_arg = (ValaDataType*) gee_iterator_get (_type_arg_it);
 				vala_data_type_add_type_argument (vala_object_creation_expression_get_type_reference (self), type_arg);
 				vala_source_file_add_type_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), type_arg, VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
 				(type_arg == NULL) ? NULL : (type_arg = (vala_code_node_unref (type_arg), NULL));
 			}
-			(type_arg_it == NULL) ? NULL : (type_arg_it = (gee_collection_object_unref (type_arg_it), NULL));
+			(_type_arg_it == NULL) ? NULL : (_type_arg_it = (gee_collection_object_unref (_type_arg_it), NULL));
 		}
 		(constructor_sym == NULL) ? NULL : (constructor_sym = (vala_code_node_unref (constructor_sym), NULL));
 		(type_sym == NULL) ? NULL : (type_sym = (vala_code_node_unref (type_sym), NULL));
@@ -415,30 +416,44 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 		if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
 			vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) vala_class_get_default_construction_method (cl));
+			if (vala_expression_get_symbol_reference ((ValaExpression*) self) != NULL) {
+				/* track usage for flow analyzer*/
+				vala_symbol_set_used (vala_expression_get_symbol_reference ((ValaExpression*) self), TRUE);
+			}
 		}
 		while (cl != NULL) {
-			ValaClass* _tmp36;
-			ValaClass* _tmp35;
-			if (VALA_TYPESYMBOL (cl) == analyzer->initially_unowned_type) {
+			char* _tmp35;
+			gboolean _tmp36;
+			ValaClass* _tmp38;
+			ValaClass* _tmp37;
+			_tmp35 = NULL;
+			if ((_tmp36 = (_tmp35 = vala_typesymbol_get_ref_sink_function ((ValaTypeSymbol*) cl)) != NULL, _tmp35 = (g_free (_tmp35), NULL), _tmp36)) {
 				vala_data_type_set_floating_reference (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
 				break;
 			}
-			_tmp36 = NULL;
-			_tmp35 = NULL;
-			cl = (_tmp36 = (_tmp35 = vala_class_get_base_class (cl), (_tmp35 == NULL) ? NULL : vala_code_node_ref (_tmp35)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp36);
+			_tmp38 = NULL;
+			_tmp37 = NULL;
+			cl = (_tmp38 = (_tmp37 = vala_class_get_base_class (cl), (_tmp37 == NULL) ? NULL : vala_code_node_ref (_tmp37)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp38);
 		}
 		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
 	} else {
 		if (VALA_IS_STRUCT (type)) {
-			ValaStruct* _tmp37;
+			ValaStruct* _tmp39;
 			ValaStruct* st;
-			GeeList* _tmp38;
-			_tmp37 = NULL;
-			st = (_tmp37 = VALA_STRUCT (type), (_tmp37 == NULL) ? NULL : vala_code_node_ref (_tmp37));
-			_tmp38 = NULL;
-			expected_num_type_args = gee_collection_get_size ((GeeCollection*) (_tmp38 = vala_struct_get_type_parameters (st)));
-			(_tmp38 == NULL) ? NULL : (_tmp38 = (gee_collection_object_unref (_tmp38), NULL));
+			GeeList* _tmp40;
+			gboolean _tmp41;
+			_tmp39 = NULL;
+			st = (_tmp39 = VALA_STRUCT (type), (_tmp39 == NULL) ? NULL : vala_code_node_ref (_tmp39));
+			_tmp40 = NULL;
+			expected_num_type_args = gee_collection_get_size ((GeeCollection*) (_tmp40 = vala_struct_get_type_parameters (st)));
+			(_tmp40 == NULL) ? NULL : (_tmp40 = (gee_collection_object_unref (_tmp40), NULL));
+			_tmp41 = FALSE;
 			if (!self->priv->_struct_creation) {
+				_tmp41 = !vala_code_context_get_deprecated (vala_semantic_analyzer_get_context (analyzer));
+			} else {
+				_tmp41 = FALSE;
+			}
+			if (_tmp41) {
 				vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), "deprecated syntax, don't use `new' to initialize structs");
 			}
 			if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
@@ -448,103 +463,107 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 	}
 	if (expected_num_type_args > given_num_type_args) {
-		gboolean _tmp39;
+		gboolean _tmp42;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "too few type arguments");
-		return (_tmp39 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp39);
+		return (_tmp42 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp42);
 	} else {
 		if (expected_num_type_args < given_num_type_args) {
-			gboolean _tmp40;
+			gboolean _tmp43;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "too many type arguments");
-			return (_tmp40 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp40);
+			return (_tmp43 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp43);
 		}
 	}
-	_tmp41 = FALSE;
+	_tmp44 = FALSE;
 	if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
-		GeeList* _tmp42;
-		_tmp42 = NULL;
-		_tmp41 = gee_collection_get_size ((GeeCollection*) (_tmp42 = vala_object_creation_expression_get_argument_list (self))) != 0;
-		(_tmp42 == NULL) ? NULL : (_tmp42 = (gee_collection_object_unref (_tmp42), NULL));
+		GeeList* _tmp45;
+		_tmp45 = NULL;
+		_tmp44 = gee_collection_get_size ((GeeCollection*) (_tmp45 = vala_object_creation_expression_get_argument_list (self))) != 0;
+		(_tmp45 == NULL) ? NULL : (_tmp45 = (gee_collection_object_unref (_tmp45), NULL));
 	} else {
-		_tmp41 = FALSE;
+		_tmp44 = FALSE;
 	}
-	if (_tmp41) {
-		char* _tmp44;
-		char* _tmp43;
-		gboolean _tmp45;
+	if (_tmp44) {
+		char* _tmp47;
+		char* _tmp46;
+		gboolean _tmp48;
 		vala_expression_set_value_type ((ValaExpression*) self, NULL);
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp44 = NULL;
-		_tmp43 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp44 = g_strdup_printf ("No arguments allowed when constructing type `%s'", _tmp43 = vala_symbol_get_full_name ((ValaSymbol*) type)));
-		_tmp44 = (g_free (_tmp44), NULL);
-		_tmp43 = (g_free (_tmp43), NULL);
-		return (_tmp45 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp45);
+		_tmp47 = NULL;
+		_tmp46 = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp47 = g_strdup_printf ("No arguments allowed when constructing type `%s'", _tmp46 = vala_symbol_get_full_name ((ValaSymbol*) type)));
+		_tmp47 = (g_free (_tmp47), NULL);
+		_tmp46 = (g_free (_tmp46), NULL);
+		return (_tmp48 = FALSE, (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp48);
 	}
 	if (VALA_IS_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-		ValaMethod* _tmp46;
+		ValaMethod* _tmp49;
 		ValaMethod* m;
 		GeeList* args;
 		GeeIterator* arg_it;
-		GeeList* _tmp50;
-		ValaMethodType* _tmp49;
-		_tmp46 = NULL;
-		m = (_tmp46 = VALA_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp46 == NULL) ? NULL : vala_code_node_ref (_tmp46));
+		GeeList* _tmp54;
+		ValaMethodType* _tmp53;
+		_tmp49 = NULL;
+		m = (_tmp49 = VALA_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp49 == NULL) ? NULL : vala_code_node_ref (_tmp49));
 		args = vala_object_creation_expression_get_argument_list (self);
 		arg_it = gee_iterable_iterator ((GeeIterable*) args);
 		{
-			GeeList* _tmp47;
-			GeeIterator* _tmp48;
-			GeeIterator* param_it;
-			_tmp47 = NULL;
-			_tmp48 = NULL;
-			param_it = (_tmp48 = gee_iterable_iterator ((GeeIterable*) (_tmp47 = vala_method_get_parameters (m))), (_tmp47 == NULL) ? NULL : (_tmp47 = (gee_collection_object_unref (_tmp47), NULL)), _tmp48);
-			while (gee_iterator_next (param_it)) {
+			GeeList* _tmp50;
+			GeeIterator* _tmp51;
+			GeeIterator* _param_it;
+			_tmp50 = NULL;
+			_tmp51 = NULL;
+			_param_it = (_tmp51 = gee_iterable_iterator ((GeeIterable*) (_tmp50 = vala_method_get_parameters (m))), (_tmp50 == NULL) ? NULL : (_tmp50 = (gee_collection_object_unref (_tmp50), NULL)), _tmp51);
+			while (gee_iterator_next (_param_it)) {
 				ValaFormalParameter* param;
-				param = (ValaFormalParameter*) gee_iterator_get (param_it);
+				param = (ValaFormalParameter*) gee_iterator_get (_param_it);
 				if (vala_formal_parameter_get_ellipsis (param)) {
 					(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
 					break;
 				}
 				if (gee_iterator_next (arg_it)) {
 					ValaExpression* arg;
+					ValaDataType* _tmp52;
 					arg = (ValaExpression*) gee_iterator_get (arg_it);
 					/* store expected type for callback parameters */
-					vala_expression_set_target_type (arg, vala_formal_parameter_get_parameter_type (param));
+					vala_expression_set_formal_target_type (arg, vala_formal_parameter_get_parameter_type (param));
+					_tmp52 = NULL;
+					vala_expression_set_target_type (arg, _tmp52 = vala_data_type_get_actual_type (vala_expression_get_formal_target_type (arg), vala_expression_get_value_type ((ValaExpression*) self), (ValaCodeNode*) self));
+					(_tmp52 == NULL) ? NULL : (_tmp52 = (vala_code_node_unref (_tmp52), NULL));
 					(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 				}
 				(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
 			}
-			(param_it == NULL) ? NULL : (param_it = (gee_collection_object_unref (param_it), NULL));
+			(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 		}
 		{
-			GeeIterator* arg_it;
-			arg_it = gee_iterable_iterator ((GeeIterable*) args);
-			while (gee_iterator_next (arg_it)) {
+			GeeIterator* _arg_it;
+			_arg_it = gee_iterable_iterator ((GeeIterable*) args);
+			while (gee_iterator_next (_arg_it)) {
 				ValaExpression* arg;
-				arg = (ValaExpression*) gee_iterator_get (arg_it);
+				arg = (ValaExpression*) gee_iterator_get (_arg_it);
 				vala_code_node_check ((ValaCodeNode*) arg, analyzer);
 				(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 			}
-			(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+			(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 		}
-		_tmp50 = NULL;
-		_tmp49 = NULL;
-		vala_semantic_analyzer_check_arguments (analyzer, (ValaExpression*) self, (ValaDataType*) (_tmp49 = vala_method_type_new (m)), _tmp50 = vala_method_get_parameters (m), args);
-		(_tmp50 == NULL) ? NULL : (_tmp50 = (gee_collection_object_unref (_tmp50), NULL));
-		(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_code_node_unref (_tmp49), NULL));
+		_tmp54 = NULL;
+		_tmp53 = NULL;
+		vala_semantic_analyzer_check_arguments (analyzer, (ValaExpression*) self, (ValaDataType*) (_tmp53 = vala_method_type_new (m)), _tmp54 = vala_method_get_parameters (m), args);
+		(_tmp54 == NULL) ? NULL : (_tmp54 = (gee_collection_object_unref (_tmp54), NULL));
+		(_tmp53 == NULL) ? NULL : (_tmp53 = (vala_code_node_unref (_tmp53), NULL));
 		{
-			GeeList* _tmp51;
-			GeeIterator* _tmp52;
-			GeeIterator* error_type_it;
-			_tmp51 = NULL;
-			_tmp52 = NULL;
-			error_type_it = (_tmp52 = gee_iterable_iterator ((GeeIterable*) (_tmp51 = vala_code_node_get_error_types ((ValaCodeNode*) m))), (_tmp51 == NULL) ? NULL : (_tmp51 = (gee_collection_object_unref (_tmp51), NULL)), _tmp52);
-			while (gee_iterator_next (error_type_it)) {
+			GeeList* _tmp55;
+			GeeIterator* _tmp56;
+			GeeIterator* _error_type_it;
+			_tmp55 = NULL;
+			_tmp56 = NULL;
+			_error_type_it = (_tmp56 = gee_iterable_iterator ((GeeIterable*) (_tmp55 = vala_code_node_get_error_types ((ValaCodeNode*) m))), (_tmp55 == NULL) ? NULL : (_tmp55 = (gee_collection_object_unref (_tmp55), NULL)), _tmp56);
+			while (gee_iterator_next (_error_type_it)) {
 				ValaDataType* error_type;
 				ValaDataType* call_error_type;
-				error_type = (ValaDataType*) gee_iterator_get (error_type_it);
+				error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
 				/* ensure we can trace back which expression may throw errors of this type*/
 				call_error_type = vala_data_type_copy (error_type);
 				vala_code_node_set_source_reference ((ValaCodeNode*) call_error_type, vala_code_node_get_source_reference ((ValaCodeNode*) self));
@@ -552,15 +571,15 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 				(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
 				(call_error_type == NULL) ? NULL : (call_error_type = (vala_code_node_unref (call_error_type), NULL));
 			}
-			(error_type_it == NULL) ? NULL : (error_type_it = (gee_collection_object_unref (error_type_it), NULL));
+			(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
 		}
 		(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
 		(args == NULL) ? NULL : (args = (gee_collection_object_unref (args), NULL));
 		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
 	} else {
 		if (VALA_IS_ERROR_TYPE (vala_object_creation_expression_get_type_reference (self))) {
-			GeeList* _tmp53;
-			gboolean _tmp54;
+			GeeList* _tmp57;
+			gboolean _tmp58;
 			if (vala_object_creation_expression_get_type_reference (self) != NULL) {
 				vala_code_node_check ((ValaCodeNode*) vala_object_creation_expression_get_type_reference (self), analyzer);
 			}
@@ -568,49 +587,49 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 				vala_code_node_check ((ValaCodeNode*) self->priv->_member_name, analyzer);
 			}
 			{
-				GeeIterator* arg_it;
-				arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
-				while (gee_iterator_next (arg_it)) {
+				GeeIterator* _arg_it;
+				_arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
+				while (gee_iterator_next (_arg_it)) {
 					ValaExpression* arg;
-					arg = (ValaExpression*) gee_iterator_get (arg_it);
+					arg = (ValaExpression*) gee_iterator_get (_arg_it);
 					vala_code_node_check ((ValaCodeNode*) arg, analyzer);
 					(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 				}
-				(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+				(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 			}
 			{
-				GeeIterator* init_it;
-				init_it = gee_iterable_iterator ((GeeIterable*) self->priv->object_initializer);
-				while (gee_iterator_next (init_it)) {
+				GeeIterator* _init_it;
+				_init_it = gee_iterable_iterator ((GeeIterable*) self->priv->object_initializer);
+				while (gee_iterator_next (_init_it)) {
 					ValaMemberInitializer* init;
-					init = (ValaMemberInitializer*) gee_iterator_get (init_it);
+					init = (ValaMemberInitializer*) gee_iterator_get (_init_it);
 					vala_code_node_check ((ValaCodeNode*) init, analyzer);
 					(init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL));
 				}
-				(init_it == NULL) ? NULL : (init_it = (gee_collection_object_unref (init_it), NULL));
+				(_init_it == NULL) ? NULL : (_init_it = (gee_collection_object_unref (_init_it), NULL));
 			}
-			_tmp53 = NULL;
-			if ((_tmp54 = gee_collection_get_size ((GeeCollection*) (_tmp53 = vala_object_creation_expression_get_argument_list (self))) == 0, (_tmp53 == NULL) ? NULL : (_tmp53 = (gee_collection_object_unref (_tmp53), NULL)), _tmp54)) {
+			_tmp57 = NULL;
+			if ((_tmp58 = gee_collection_get_size ((GeeCollection*) (_tmp57 = vala_object_creation_expression_get_argument_list (self))) == 0, (_tmp57 == NULL) ? NULL : (_tmp57 = (gee_collection_object_unref (_tmp57), NULL)), _tmp58)) {
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Too few arguments, errors need at least 1 argument");
 			} else {
-				GeeList* _tmp55;
-				GeeIterator* _tmp56;
+				GeeList* _tmp59;
+				GeeIterator* _tmp60;
 				GeeIterator* arg_it;
 				ValaExpression* ex;
-				gboolean _tmp57;
-				_tmp55 = NULL;
-				_tmp56 = NULL;
-				arg_it = (_tmp56 = gee_iterable_iterator ((GeeIterable*) (_tmp55 = vala_object_creation_expression_get_argument_list (self))), (_tmp55 == NULL) ? NULL : (_tmp55 = (gee_collection_object_unref (_tmp55), NULL)), _tmp56);
+				gboolean _tmp61;
+				_tmp59 = NULL;
+				_tmp60 = NULL;
+				arg_it = (_tmp60 = gee_iterable_iterator ((GeeIterable*) (_tmp59 = vala_object_creation_expression_get_argument_list (self))), (_tmp59 == NULL) ? NULL : (_tmp59 = (gee_collection_object_unref (_tmp59), NULL)), _tmp60);
 				gee_iterator_next (arg_it);
 				ex = (ValaExpression*) gee_iterator_get (arg_it);
-				_tmp57 = FALSE;
+				_tmp61 = FALSE;
 				if (vala_expression_get_value_type (ex) == NULL) {
-					_tmp57 = TRUE;
+					_tmp61 = TRUE;
 				} else {
-					_tmp57 = !vala_data_type_compatible (vala_expression_get_value_type (ex), analyzer->string_type);
+					_tmp61 = !vala_data_type_compatible (vala_expression_get_value_type (ex), analyzer->string_type);
 				}
-				if (_tmp57) {
+				if (_tmp61) {
 					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Invalid type for argument 1");
 				}
@@ -620,21 +639,21 @@ static gboolean vala_object_creation_expression_real_check (ValaCodeNode* base,
 		}
 	}
 	{
-		GeeList* _tmp58;
-		GeeIterator* _tmp59;
-		GeeIterator* init_it;
-		_tmp58 = NULL;
-		_tmp59 = NULL;
-		init_it = (_tmp59 = gee_iterable_iterator ((GeeIterable*) (_tmp58 = vala_object_creation_expression_get_object_initializer (self))), (_tmp58 == NULL) ? NULL : (_tmp58 = (gee_collection_object_unref (_tmp58), NULL)), _tmp59);
-		while (gee_iterator_next (init_it)) {
+		GeeList* _tmp62;
+		GeeIterator* _tmp63;
+		GeeIterator* _init_it;
+		_tmp62 = NULL;
+		_tmp63 = NULL;
+		_init_it = (_tmp63 = gee_iterable_iterator ((GeeIterable*) (_tmp62 = vala_object_creation_expression_get_object_initializer (self))), (_tmp62 == NULL) ? NULL : (_tmp62 = (gee_collection_object_unref (_tmp62), NULL)), _tmp63);
+		while (gee_iterator_next (_init_it)) {
 			ValaMemberInitializer* init;
-			init = (ValaMemberInitializer*) gee_iterator_get (init_it);
+			init = (ValaMemberInitializer*) gee_iterator_get (_init_it);
 			vala_semantic_analyzer_visit_member_initializer (analyzer, init, vala_object_creation_expression_get_type_reference (self));
 			(init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL));
 		}
-		(init_it == NULL) ? NULL : (init_it = (gee_collection_object_unref (init_it), NULL));
+		(_init_it == NULL) ? NULL : (_init_it = (gee_collection_object_unref (_init_it), NULL));
 	}
-	return (_tmp60 = !vala_code_node_get_error ((ValaCodeNode*) self), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp60);
+	return (_tmp64 = !vala_code_node_get_error ((ValaCodeNode*) self), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp64);
 }
 
 
@@ -643,15 +662,15 @@ static void vala_object_creation_expression_real_get_defined_variables (ValaCode
 	self = (ValaObjectCreationExpression*) base;
 	g_return_if_fail (collection != NULL);
 	{
-		GeeIterator* arg_it;
-		arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
-		while (gee_iterator_next (arg_it)) {
+		GeeIterator* _arg_it;
+		_arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
+		while (gee_iterator_next (_arg_it)) {
 			ValaExpression* arg;
-			arg = (ValaExpression*) gee_iterator_get (arg_it);
+			arg = (ValaExpression*) gee_iterator_get (_arg_it);
 			vala_code_node_get_defined_variables ((ValaCodeNode*) arg, collection);
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
 }
 
@@ -661,15 +680,15 @@ static void vala_object_creation_expression_real_get_used_variables (ValaCodeNod
 	self = (ValaObjectCreationExpression*) base;
 	g_return_if_fail (collection != NULL);
 	{
-		GeeIterator* arg_it;
-		arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
-		while (gee_iterator_next (arg_it)) {
+		GeeIterator* _arg_it;
+		_arg_it = gee_iterable_iterator ((GeeIterable*) self->priv->argument_list);
+		while (gee_iterator_next (_arg_it)) {
 			ValaExpression* arg;
-			arg = (ValaExpression*) gee_iterator_get (arg_it);
+			arg = (ValaExpression*) gee_iterator_get (_arg_it);
 			vala_code_node_get_used_variables ((ValaCodeNode*) arg, collection);
 			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
 		}
-		(arg_it == NULL) ? NULL : (arg_it = (gee_collection_object_unref (arg_it), NULL));
+		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
 }
 
