@@ -1,6 +1,6 @@
 /* valapointerindirection.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -47,15 +48,19 @@ struct _ValaPointerIndirection {
 	ValaExpression parent_instance;
 	ValaPointerIndirectionPrivate * priv;
 };
+
 struct _ValaPointerIndirectionClass {
 	ValaExpressionClass parent_class;
 };
 
+
+ValaPointerIndirection* vala_pointer_indirection_construct (GType object_type, ValaExpression* inner, ValaSourceReference* source_reference);
 ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaExpression* vala_pointer_indirection_get_inner (ValaPointerIndirection* self);
 void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpression* value);
 GType vala_pointer_indirection_get_type (void);
 
+
 G_END_DECLS
 
 #endif
