@@ -29,6 +29,7 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodenode.h>
+#include <gee/map.h>
 #include <vala/valastruct.h>
 #include <vala/valadatatype.h>
 #include <vala/valavoidtype.h>
@@ -45,13 +46,13 @@
 #include <gee/collection.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
+#include <vala/valaerrortype.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valaerrorcode.h>
 #include <vala/valadelegate.h>
 #include <vala/valafield.h>
 #include <vala/valaexpression.h>
 #include <vala/valacreationmethod.h>
-#include <vala/valaerrortype.h>
-#include <vala/valaerrordomain.h>
-#include <vala/valaerrorcode.h>
 #include <vala/valaclass.h>
 #include <vala/valasignal.h>
 #include <vala/valaproperty.h>
@@ -60,7 +61,6 @@
 #include <vala/valainterface.h>
 #include <vala/valaconstant.h>
 #include <glib/gstdio.h>
-#include <gee/map.h>
 #include "vapigen/valamarkupreader.h"
 
 
@@ -96,9 +96,8 @@ static ValaStruct* vala_gir_parser_parse_alias (ValaGirParser* self);
 static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self);
 static ValaEnum* vala_gir_parser_parse_bitfield (ValaGirParser* self);
 static ValaEnumValue* vala_gir_parser_parse_enumeration_member (ValaGirParser* self);
-static ValaMethod* vala_gir_parser_parse_function (ValaGirParser* self);
 static ValaDataType* vala_gir_parser_parse_return_value (ValaGirParser* self);
-static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self, gint* array_length_idx);
+static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self, gint* array_length_idx, gint* closure_idx, gint* destroy_idx);
 static ValaDataType* vala_gir_parser_parse_type (ValaGirParser* self, gint* array_length_index);
 static ValaDataType* vala_gir_parser_parse_type_from_name (ValaGirParser* self, const char* type_name);
 static char* vala_gir_parser_transform_namespace_name (ValaGirParser* self, const char* gir_module_name);
@@ -109,8 +108,7 @@ static ValaField* vala_gir_parser_parse_field (ValaGirParser* self);
 static ValaProperty* vala_gir_parser_parse_property (ValaGirParser* self);
 static ValaDelegate* vala_gir_parser_parse_callback (ValaGirParser* self);
 static ValaMethod* vala_gir_parser_parse_constructor (ValaGirParser* self);
-static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self);
-static ValaMethod* vala_gir_parser_parse_vmethod (ValaGirParser* self);
+static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self, const char* element_name);
 static ValaSignal* vala_gir_parser_parse_signal (ValaGirParser* self);
 static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self);
 static ValaStruct* vala_gir_parser_parse_union (ValaGirParser* self);
@@ -457,7 +455,7 @@ static ValaNamespace* vala_gir_parser_parse_namespace (ValaGirParser* self) {
 					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "function") == 0) {
 						ValaSymbol* _tmp9;
 						_tmp9 = NULL;
-						sym = (_tmp9 = (ValaSymbol*) vala_gir_parser_parse_function (self), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp9);
+						sym = (_tmp9 = (ValaSymbol*) vala_gir_parser_parse_method (self, "function"), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp9);
 					} else {
 						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "callback") == 0) {
 							ValaSymbol* _tmp10;
@@ -579,7 +577,7 @@ static ValaStruct* vala_gir_parser_parse_alias (ValaGirParser* self) {
 	vala_symbol_set_access ((ValaSymbol*) st, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	vala_struct_add_base_type (st, _tmp4 = vala_gir_parser_parse_type_from_name (self, _tmp3 = vala_markup_reader_get_attribute (self->priv->reader, "target")));
+	vala_struct_set_base_type (st, _tmp4 = vala_gir_parser_parse_type_from_name (self, _tmp3 = vala_markup_reader_get_attribute (self->priv->reader, "target")));
 	(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL));
 	_tmp3 = (g_free (_tmp3), NULL);
 	vala_gir_parser_next (self);
@@ -593,6 +591,7 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	char* _tmp0;
 	ValaEnum* _tmp2;
 	ValaEnum* en;
+	char* enum_cname;
 	char* common_prefix;
 	ValaEnum* _tmp12;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -602,6 +601,10 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	_tmp2 = NULL;
 	en = (_tmp2 = vala_enum_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) en, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	enum_cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (enum_cname != NULL) {
+		vala_enum_set_cname (en, enum_cname);
+	}
 	vala_gir_parser_next (self);
 	common_prefix = NULL;
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
@@ -652,14 +655,14 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 					} else {
 						gboolean _tmp10;
 						_tmp10 = FALSE;
-						if ((g_unichar_isdigit (g_utf8_get_char (g_utf8_offset_to_pointer (cname, strlen (common_prefix)))))) {
+						if (g_unichar_isdigit (g_utf8_get_char (g_utf8_offset_to_pointer (cname, strlen (common_prefix))))) {
 							_tmp10 = (g_utf8_strlen (cname, -1) - g_utf8_strlen (common_prefix, -1)) <= 1;
 						} else {
 							_tmp10 = FALSE;
 						}
 						_tmp9 = _tmp10;
 					}
-					_tmp8 = (_tmp9);
+					_tmp8 = _tmp9;
 				} else {
 					_tmp8 = FALSE;
 				}
@@ -680,7 +683,7 @@ static ValaEnum* vala_gir_parser_parse_enumeration (ValaGirParser* self) {
 	vala_enum_set_cprefix (en, common_prefix);
 	vala_gir_parser_end_element (self, "enumeration");
 	_tmp12 = NULL;
-	return (_tmp12 = en, common_prefix = (g_free (common_prefix), NULL), _tmp12);
+	return (_tmp12 = en, enum_cname = (g_free (enum_cname), NULL), common_prefix = (g_free (common_prefix), NULL), _tmp12);
 }
 
 
@@ -741,88 +744,6 @@ static ValaEnumValue* vala_gir_parser_parse_enumeration_member (ValaGirParser* s
 }
 
 
-static ValaMethod* vala_gir_parser_parse_function (ValaGirParser* self) {
-	char* name;
-	ValaDataType* return_type;
-	gboolean _tmp0;
-	ValaSourceReference* _tmp3;
-	ValaMethod* _tmp4;
-	ValaMethod* m;
-	GeeArrayList* parameters;
-	GeeArrayList* array_length_parameters;
-	gboolean _tmp5;
-	gint i;
-	ValaMethod* _tmp6;
-	g_return_val_if_fail (self != NULL, NULL);
-	vala_gir_parser_start_element (self, "function");
-	name = vala_markup_reader_get_attribute (self->priv->reader, "name");
-	vala_gir_parser_next (self);
-	return_type = NULL;
-	_tmp0 = FALSE;
-	if (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-		_tmp0 = _vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "return-value") == 0;
-	} else {
-		_tmp0 = FALSE;
-	}
-	if (_tmp0) {
-		ValaDataType* _tmp1;
-		_tmp1 = NULL;
-		return_type = (_tmp1 = vala_gir_parser_parse_return_value (self), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp1);
-	} else {
-		ValaDataType* _tmp2;
-		_tmp2 = NULL;
-		return_type = (_tmp2 = (ValaDataType*) vala_void_type_new (NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp2);
-	}
-	_tmp3 = NULL;
-	_tmp4 = NULL;
-	m = (_tmp4 = vala_method_new (name, return_type, _tmp3 = vala_gir_parser_get_current_src (self)), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_source_reference_unref (_tmp3), NULL)), _tmp4);
-	vala_symbol_set_access ((ValaSymbol*) m, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-	vala_method_set_binding (m, MEMBER_BINDING_STATIC);
-	parameters = gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
-	array_length_parameters = gee_array_list_new (G_TYPE_INT, NULL, NULL, g_direct_equal);
-	_tmp5 = FALSE;
-	if (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-		_tmp5 = _vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "parameters") == 0;
-	} else {
-		_tmp5 = FALSE;
-	}
-	if (_tmp5) {
-		vala_gir_parser_start_element (self, "parameters");
-		vala_gir_parser_next (self);
-		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-			gint array_length_idx;
-			ValaFormalParameter* param;
-			array_length_idx = 0;
-			param = vala_gir_parser_parse_parameter (self, &array_length_idx);
-			if (array_length_idx != (-1)) {
-				gee_collection_add ((GeeCollection*) array_length_parameters, GINT_TO_POINTER (array_length_idx));
-			}
-			gee_collection_add ((GeeCollection*) parameters, param);
-			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
-		}
-		vala_gir_parser_end_element (self, "parameters");
-	}
-	i = 0;
-	{
-		GeeIterator* _param_it;
-		_param_it = gee_iterable_iterator ((GeeIterable*) parameters);
-		while (gee_iterator_next (_param_it)) {
-			ValaFormalParameter* param;
-			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
-			if (!gee_collection_contains ((GeeCollection*) array_length_parameters, GINT_TO_POINTER (i))) {
-				vala_method_add_parameter (m, param);
-			}
-			i++;
-			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
-		}
-		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
-	}
-	vala_gir_parser_end_element (self, "function");
-	_tmp6 = NULL;
-	return (_tmp6 = m, name = (g_free (name), NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), (parameters == NULL) ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL)), (array_length_parameters == NULL) ? NULL : (array_length_parameters = (gee_collection_object_unref (array_length_parameters), NULL)), _tmp6);
-}
-
-
 static ValaDataType* vala_gir_parser_parse_return_value (ValaGirParser* self) {
 	char* transfer;
 	ValaDataType* type;
@@ -841,38 +762,68 @@ static ValaDataType* vala_gir_parser_parse_return_value (ValaGirParser* self) {
 }
 
 
-static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self, gint* array_length_idx) {
+static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self, gint* array_length_idx, gint* closure_idx, gint* destroy_idx) {
 	ValaFormalParameter* param;
 	char* name;
 	char* direction;
 	char* transfer;
 	char* allow_none;
-	ValaFormalParameter* _tmp4;
+	char* closure;
+	char* destroy;
+	gboolean _tmp0;
+	gboolean _tmp1;
+	ValaFormalParameter* _tmp6;
 	g_return_val_if_fail (self != NULL, NULL);
 	param = NULL;
 	if ((&(*array_length_idx)) != NULL) {
 		(*array_length_idx) = -1;
 	}
+	if ((&(*closure_idx)) != NULL) {
+		(*closure_idx) = -1;
+	}
+	if ((&(*destroy_idx)) != NULL) {
+		(*destroy_idx) = -1;
+	}
 	vala_gir_parser_start_element (self, "parameter");
 	name = vala_markup_reader_get_attribute (self->priv->reader, "name");
 	direction = vala_markup_reader_get_attribute (self->priv->reader, "direction");
 	transfer = vala_markup_reader_get_attribute (self->priv->reader, "transfer-ownership");
 	allow_none = vala_markup_reader_get_attribute (self->priv->reader, "allow-none");
+	closure = vala_markup_reader_get_attribute (self->priv->reader, "closure");
+	destroy = vala_markup_reader_get_attribute (self->priv->reader, "destroy");
+	_tmp0 = FALSE;
+	if (closure != NULL) {
+		_tmp0 = (&(*closure_idx)) != NULL;
+	} else {
+		_tmp0 = FALSE;
+	}
+	if (_tmp0) {
+		(*closure_idx) = atoi (closure);
+	}
+	_tmp1 = FALSE;
+	if (destroy != NULL) {
+		_tmp1 = (&(*destroy_idx)) != NULL;
+	} else {
+		_tmp1 = FALSE;
+	}
+	if (_tmp1) {
+		(*destroy_idx) = atoi (destroy);
+	}
 	vala_gir_parser_next (self);
 	if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "varargs") == 0) {
-		ValaFormalParameter* _tmp1;
-		ValaSourceReference* _tmp0;
+		ValaFormalParameter* _tmp3;
+		ValaSourceReference* _tmp2;
 		vala_gir_parser_start_element (self, "varargs");
 		vala_gir_parser_next (self);
-		_tmp1 = NULL;
-		_tmp0 = NULL;
-		param = (_tmp1 = vala_formal_parameter_new_with_ellipsis (_tmp0 = vala_gir_parser_get_current_src (self)), (param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL)), _tmp1);
-		(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_source_reference_unref (_tmp0), NULL));
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		param = (_tmp3 = vala_formal_parameter_new_with_ellipsis (_tmp2 = vala_gir_parser_get_current_src (self)), (param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL)), _tmp3);
+		(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_source_reference_unref (_tmp2), NULL));
 		vala_gir_parser_end_element (self, "varargs");
 	} else {
 		ValaDataType* type;
-		ValaFormalParameter* _tmp3;
-		ValaSourceReference* _tmp2;
+		ValaFormalParameter* _tmp5;
+		ValaSourceReference* _tmp4;
 		type = vala_gir_parser_parse_type (self, &(*array_length_idx));
 		if (_vala_strcmp0 (transfer, "full") == 0) {
 			vala_data_type_set_value_owned (type, TRUE);
@@ -880,10 +831,10 @@ static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self
 		if (_vala_strcmp0 (allow_none, "1") == 0) {
 			vala_data_type_set_nullable (type, TRUE);
 		}
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		param = (_tmp3 = vala_formal_parameter_new (name, type, _tmp2 = vala_gir_parser_get_current_src (self)), (param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL)), _tmp3);
-		(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_source_reference_unref (_tmp2), NULL));
+		_tmp5 = NULL;
+		_tmp4 = NULL;
+		param = (_tmp5 = vala_formal_parameter_new (name, type, _tmp4 = vala_gir_parser_get_current_src (self)), (param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL)), _tmp5);
+		(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_source_reference_unref (_tmp4), NULL));
 		if (_vala_strcmp0 (direction, "out") == 0) {
 			vala_formal_parameter_set_direction (param, VALA_PARAMETER_DIRECTION_OUT);
 		} else {
@@ -894,8 +845,8 @@ static ValaFormalParameter* vala_gir_parser_parse_parameter (ValaGirParser* self
 		(type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL));
 	}
 	vala_gir_parser_end_element (self, "parameter");
-	_tmp4 = NULL;
-	return (_tmp4 = param, name = (g_free (name), NULL), direction = (g_free (direction), NULL), transfer = (g_free (transfer), NULL), allow_none = (g_free (allow_none), NULL), _tmp4);
+	_tmp6 = NULL;
+	return (_tmp6 = param, name = (g_free (name), NULL), direction = (g_free (direction), NULL), transfer = (g_free (transfer), NULL), allow_none = (g_free (allow_none), NULL), closure = (g_free (closure), NULL), destroy = (g_free (destroy), NULL), _tmp6);
 }
 
 
@@ -1101,7 +1052,7 @@ static ValaStruct* vala_gir_parser_parse_record (ValaGirParser* self) {
 					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 						ValaMethod* _tmp6;
 						_tmp6 = NULL;
-						_tmp6 = vala_gir_parser_parse_method (self);
+						vala_struct_add_method (st, _tmp6 = vala_gir_parser_parse_method (self, "method"));
 						(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
 					} else {
 						char* _tmp8;
@@ -1128,6 +1079,7 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	char* _tmp0;
 	ValaClass* _tmp2;
 	ValaClass* cl;
+	char* cname;
 	char* parent;
 	GeeArrayList* signals;
 	GeeArrayList* methods;
@@ -1141,6 +1093,10 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	_tmp2 = NULL;
 	cl = (_tmp2 = vala_class_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) cl, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_class_set_cname (cl, cname);
+	}
 	parent = vala_markup_reader_get_attribute (self->priv->reader, "parent");
 	if (parent != NULL) {
 		ValaDataType* _tmp3;
@@ -1187,19 +1143,19 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "function") == 0) {
 							ValaMethod* _tmp9;
 							_tmp9 = NULL;
-							gee_collection_add ((GeeCollection*) methods, _tmp9 = vala_gir_parser_parse_function (self));
+							gee_collection_add ((GeeCollection*) methods, _tmp9 = vala_gir_parser_parse_method (self, "function"));
 							(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
 						} else {
 							if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 								ValaMethod* _tmp10;
 								_tmp10 = NULL;
-								gee_collection_add ((GeeCollection*) methods, _tmp10 = vala_gir_parser_parse_method (self));
+								gee_collection_add ((GeeCollection*) methods, _tmp10 = vala_gir_parser_parse_method (self, "method"));
 								(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
 							} else {
 								if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "callback") == 0) {
 									ValaMethod* _tmp11;
 									_tmp11 = NULL;
-									gee_collection_add ((GeeCollection*) vmethods, _tmp11 = vala_gir_parser_parse_vmethod (self));
+									gee_collection_add ((GeeCollection*) vmethods, _tmp11 = vala_gir_parser_parse_method (self, "callback"));
 									(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_code_node_unref (_tmp11), NULL));
 								} else {
 									if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "glib:signal") == 0) {
@@ -1379,7 +1335,7 @@ static ValaClass* vala_gir_parser_parse_class (ValaGirParser* self) {
 	}
 	vala_gir_parser_end_element (self, "class");
 	_tmp25 = NULL;
-	return (_tmp25 = cl, parent = (g_free (parent), NULL), (signals == NULL) ? NULL : (signals = (gee_collection_object_unref (signals), NULL)), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), (fields == NULL) ? NULL : (fields = (gee_collection_object_unref (fields), NULL)), _tmp25);
+	return (_tmp25 = cl, cname = (g_free (cname), NULL), parent = (g_free (parent), NULL), (signals == NULL) ? NULL : (signals = (gee_collection_object_unref (signals), NULL)), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), (fields == NULL) ? NULL : (fields = (gee_collection_object_unref (fields), NULL)), _tmp25);
 }
 
 
@@ -1388,8 +1344,10 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 	char* _tmp0;
 	ValaInterface* _tmp2;
 	ValaInterface* iface;
+	char* cname;
 	GeeArrayList* methods;
-	ValaInterface* _tmp15;
+	GeeArrayList* vmethods;
+	ValaInterface* _tmp18;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_gir_parser_start_element (self, "interface");
 	_tmp1 = NULL;
@@ -1397,8 +1355,13 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 	_tmp2 = NULL;
 	iface = (_tmp2 = vala_interface_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "name"), _tmp1 = vala_gir_parser_get_current_src (self)), (_tmp1 == NULL) ? NULL : (_tmp1 = (vala_source_reference_unref (_tmp1), NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	vala_symbol_set_access ((ValaSymbol*) iface, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_interface_set_cname (iface, cname);
+	}
 	vala_gir_parser_next (self);
 	methods = gee_array_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
+	vmethods = gee_array_list_new (VALA_TYPE_METHOD, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 		if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "prerequisite") == 0) {
 			ValaDataType* _tmp4;
@@ -1425,15 +1388,15 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 					(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
 				} else {
 					if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "callback") == 0) {
-						ValaDelegate* _tmp7;
+						ValaMethod* _tmp7;
 						_tmp7 = NULL;
-						_tmp7 = vala_gir_parser_parse_callback (self);
+						gee_collection_add ((GeeCollection*) vmethods, _tmp7 = vala_gir_parser_parse_method (self, "callback"));
 						(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
 					} else {
 						if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 							ValaMethod* _tmp8;
 							_tmp8 = NULL;
-							gee_collection_add ((GeeCollection*) methods, _tmp8 = vala_gir_parser_parse_method (self));
+							gee_collection_add ((GeeCollection*) methods, _tmp8 = vala_gir_parser_parse_method (self, "method"));
 							(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_code_node_unref (_tmp8), NULL));
 						} else {
 							if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "glib:signal") == 0) {
@@ -1458,16 +1421,16 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 			}
 		}
 	}
-	/* method merging*/
+	/* virtual method merging*/
 	{
 		GeeIterator* _m_it;
-		/* method merging*/
-		_m_it = gee_iterable_iterator ((GeeIterable*) methods);
-		/* method merging*/
+		/* virtual method merging*/
+		_m_it = gee_iterable_iterator ((GeeIterable*) vmethods);
+		/* virtual method merging*/
 		while (gee_iterator_next (_m_it)) {
 			ValaMethod* m;
 			ValaSymbol* symbol;
-			/* method merging*/
+			/* virtual method merging*/
 			m = (ValaMethod*) gee_iterator_get (_m_it);
 			symbol = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) iface), vala_symbol_get_name ((ValaSymbol*) m));
 			if (symbol == NULL) {
@@ -1478,7 +1441,7 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 					ValaSignal* sig;
 					_tmp12 = NULL;
 					sig = (_tmp12 = VALA_SIGNAL (symbol), (_tmp12 == NULL) ? NULL : vala_code_node_ref (_tmp12));
-					vala_signal_set_has_emitter (sig, TRUE);
+					vala_signal_set_is_virtual (sig, TRUE);
 					(sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL));
 				} else {
 					char* _tmp14;
@@ -1495,9 +1458,50 @@ static ValaInterface* vala_gir_parser_parse_interface (ValaGirParser* self) {
 		}
 		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
 	}
+	/* method merging*/
+	{
+		GeeIterator* _m_it;
+		/* method merging*/
+		_m_it = gee_iterable_iterator ((GeeIterable*) methods);
+		/* method merging*/
+		while (gee_iterator_next (_m_it)) {
+			ValaMethod* m;
+			ValaSymbol* symbol;
+			/* method merging*/
+			m = (ValaMethod*) gee_iterator_get (_m_it);
+			symbol = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) iface), vala_symbol_get_name ((ValaSymbol*) m));
+			if (symbol == NULL) {
+				vala_interface_add_method (iface, m);
+			} else {
+				if (VALA_IS_SIGNAL (symbol)) {
+					ValaSignal* _tmp15;
+					ValaSignal* sig;
+					_tmp15 = NULL;
+					sig = (_tmp15 = VALA_SIGNAL (symbol), (_tmp15 == NULL) ? NULL : vala_code_node_ref (_tmp15));
+					vala_signal_set_has_emitter (sig, TRUE);
+					(sig == NULL) ? NULL : (sig = (vala_code_node_unref (sig), NULL));
+				} else {
+					if (VALA_IS_METHOD (symbol)) {
+					} else {
+						char* _tmp17;
+						ValaSourceReference* _tmp16;
+						/* assume method is wrapper for virtual method*/
+						_tmp17 = NULL;
+						_tmp16 = NULL;
+						vala_report_error (_tmp16 = vala_gir_parser_get_current_src (self), _tmp17 = g_strdup_printf ("duplicate member `%s' in `%s'", vala_symbol_get_name ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) iface)));
+						_tmp17 = (g_free (_tmp17), NULL);
+						(_tmp16 == NULL) ? NULL : (_tmp16 = (vala_source_reference_unref (_tmp16), NULL));
+					}
+				}
+			}
+			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+			(symbol == NULL) ? NULL : (symbol = (vala_code_node_unref (symbol), NULL));
+		}
+		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
+	}
 	vala_gir_parser_end_element (self, "interface");
-	_tmp15 = NULL;
-	return (_tmp15 = iface, (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), _tmp15);
+	_tmp18 = NULL;
+	return (_tmp18 = iface, cname = (g_free (cname), NULL), (methods == NULL) ? NULL : (methods = (gee_collection_object_unref (methods), NULL)), (vmethods == NULL) ? NULL : (vmethods = (gee_collection_object_unref (vmethods), NULL)), _tmp18);
 }
 
 
@@ -1575,7 +1579,7 @@ static ValaProperty* vala_gir_parser_parse_property (ValaGirParser* self) {
 		ValaDataType* _tmp9;
 		_tmp10 = NULL;
 		_tmp9 = NULL;
-		vala_property_set_set_accessor (prop, _tmp10 = vala_property_accessor_new (FALSE, (_vala_strcmp0 (writable, "1") == 0), (_vala_strcmp0 (construct_, "1") == 0), _tmp9 = vala_data_type_copy (vala_property_get_property_type (prop)), NULL, NULL));
+		vala_property_set_set_accessor (prop, _tmp10 = vala_property_accessor_new (FALSE, _vala_strcmp0 (writable, "1") == 0, _vala_strcmp0 (construct_, "1") == 0, _tmp9 = vala_data_type_copy (vala_property_get_property_type (prop)), NULL, NULL));
 		(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_code_node_unref (_tmp10), NULL));
 		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
 	}
@@ -1630,7 +1634,7 @@ static ValaDelegate* vala_gir_parser_parse_callback (ValaGirParser* self) {
 		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 			ValaFormalParameter* _tmp6;
 			_tmp6 = NULL;
-			vala_delegate_add_parameter (d, _tmp6 = vala_gir_parser_parse_parameter (self, NULL));
+			vala_delegate_add_parameter (d, _tmp6 = vala_gir_parser_parse_parameter (self, NULL, NULL, NULL));
 			(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
 		}
 		vala_gir_parser_end_element (self, "parameters");
@@ -1676,7 +1680,7 @@ static ValaMethod* vala_gir_parser_parse_constructor (ValaGirParser* self) {
 		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 			ValaFormalParameter* _tmp4;
 			_tmp4 = NULL;
-			vala_method_add_parameter ((ValaMethod*) m, _tmp4 = vala_gir_parser_parse_parameter (self, NULL));
+			vala_method_add_parameter ((ValaMethod*) m, _tmp4 = vala_gir_parser_parse_parameter (self, NULL, NULL, NULL));
 			(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL));
 		}
 		vala_gir_parser_end_element (self, "parameters");
@@ -1687,7 +1691,7 @@ static ValaMethod* vala_gir_parser_parse_constructor (ValaGirParser* self) {
 }
 
 
-static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self) {
+static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self, const char* element_name) {
 	char* name;
 	char* throws_string;
 	ValaDataType* return_type;
@@ -1695,10 +1699,16 @@ static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self) {
 	ValaSourceReference* _tmp3;
 	ValaMethod* _tmp4;
 	ValaMethod* m;
+	GeeArrayList* parameters;
+	GeeArrayList* array_length_parameters;
+	GeeArrayList* closure_parameters;
+	GeeArrayList* destroy_parameters;
 	gboolean _tmp5;
-	ValaMethod* _tmp8;
+	gint i;
+	ValaMethod* _tmp10;
 	g_return_val_if_fail (self != NULL, NULL);
-	vala_gir_parser_start_element (self, "method");
+	g_return_val_if_fail (element_name != NULL, NULL);
+	vala_gir_parser_start_element (self, element_name);
 	name = vala_markup_reader_get_attribute (self->priv->reader, "name");
 	throws_string = vala_markup_reader_get_attribute (self->priv->reader, "throws");
 	vala_gir_parser_next (self);
@@ -1722,71 +1732,17 @@ static ValaMethod* vala_gir_parser_parse_method (ValaGirParser* self) {
 	_tmp4 = NULL;
 	m = (_tmp4 = vala_method_new (name, return_type, _tmp3 = vala_gir_parser_get_current_src (self)), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_source_reference_unref (_tmp3), NULL)), _tmp4);
 	vala_symbol_set_access ((ValaSymbol*) m, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-	_tmp5 = FALSE;
-	if (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-		_tmp5 = _vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "parameters") == 0;
+	if (_vala_strcmp0 (element_name, "callback") == 0) {
+		vala_method_set_is_virtual (m, TRUE);
 	} else {
-		_tmp5 = FALSE;
-	}
-	if (_tmp5) {
-		vala_gir_parser_start_element (self, "parameters");
-		vala_gir_parser_next (self);
-		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-			ValaFormalParameter* _tmp6;
-			_tmp6 = NULL;
-			vala_method_add_parameter (m, _tmp6 = vala_gir_parser_parse_parameter (self, NULL));
-			(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
+		if (_vala_strcmp0 (element_name, "function") == 0) {
+			vala_method_set_binding (m, MEMBER_BINDING_STATIC);
 		}
-		vala_gir_parser_end_element (self, "parameters");
 	}
-	if (_vala_strcmp0 (throws_string, "1") == 0) {
-		ValaErrorType* _tmp7;
-		_tmp7 = NULL;
-		vala_code_node_add_error_type ((ValaCodeNode*) m, (ValaDataType*) (_tmp7 = vala_error_type_new (NULL, NULL, NULL)));
-		(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_code_node_unref (_tmp7), NULL));
-	}
-	vala_gir_parser_end_element (self, "method");
-	_tmp8 = NULL;
-	return (_tmp8 = m, name = (g_free (name), NULL), throws_string = (g_free (throws_string), NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp8);
-}
-
-
-static ValaMethod* vala_gir_parser_parse_vmethod (ValaGirParser* self) {
-	char* name;
-	char* throws_string;
-	ValaDataType* return_type;
-	gboolean _tmp0;
-	ValaSourceReference* _tmp3;
-	ValaMethod* _tmp4;
-	ValaMethod* m;
-	gboolean _tmp5;
-	ValaMethod* _tmp7;
-	g_return_val_if_fail (self != NULL, NULL);
-	vala_gir_parser_start_element (self, "callback");
-	name = vala_markup_reader_get_attribute (self->priv->reader, "name");
-	throws_string = vala_markup_reader_get_attribute (self->priv->reader, "throws");
-	vala_gir_parser_next (self);
-	return_type = NULL;
-	_tmp0 = FALSE;
-	if (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
-		_tmp0 = _vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "return-value") == 0;
-	} else {
-		_tmp0 = FALSE;
-	}
-	if (_tmp0) {
-		ValaDataType* _tmp1;
-		_tmp1 = NULL;
-		return_type = (_tmp1 = vala_gir_parser_parse_return_value (self), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp1);
-	} else {
-		ValaDataType* _tmp2;
-		_tmp2 = NULL;
-		return_type = (_tmp2 = (ValaDataType*) vala_void_type_new (NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp2);
-	}
-	_tmp3 = NULL;
-	_tmp4 = NULL;
-	m = (_tmp4 = vala_method_new (name, return_type, _tmp3 = vala_gir_parser_get_current_src (self)), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_source_reference_unref (_tmp3), NULL)), _tmp4);
-	vala_symbol_set_access ((ValaSymbol*) m, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-	vala_method_set_is_virtual (m, TRUE);
+	parameters = gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
+	array_length_parameters = gee_array_list_new (G_TYPE_INT, NULL, NULL, g_direct_equal);
+	closure_parameters = gee_array_list_new (G_TYPE_INT, NULL, NULL, g_direct_equal);
+	destroy_parameters = gee_array_list_new (G_TYPE_INT, NULL, NULL, g_direct_equal);
 	_tmp5 = FALSE;
 	if (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 		_tmp5 = _vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "parameters") == 0;
@@ -1799,11 +1755,33 @@ static ValaMethod* vala_gir_parser_parse_vmethod (ValaGirParser* self) {
 		vala_gir_parser_next (self);
 		first = TRUE;
 		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
+			gint array_length_idx;
+			gint closure_idx;
+			gint destroy_idx;
 			ValaFormalParameter* param;
-			param = vala_gir_parser_parse_parameter (self, NULL);
-			/* first parameter is instance pointer, ignore*/
-			if (!first) {
-				vala_method_add_parameter (m, param);
+			gboolean _tmp6;
+			array_length_idx = 0;
+			closure_idx = 0;
+			destroy_idx = 0;
+			param = vala_gir_parser_parse_parameter (self, &array_length_idx, &closure_idx, &destroy_idx);
+			if (array_length_idx != (-1)) {
+				gee_collection_add ((GeeCollection*) array_length_parameters, GINT_TO_POINTER (array_length_idx));
+			}
+			if (closure_idx != (-1)) {
+				gee_collection_add ((GeeCollection*) closure_parameters, GINT_TO_POINTER (closure_idx));
+			}
+			if (destroy_idx != (-1)) {
+				gee_collection_add ((GeeCollection*) destroy_parameters, GINT_TO_POINTER (destroy_idx));
+			}
+			_tmp6 = FALSE;
+			if (_vala_strcmp0 (element_name, "callback") != 0) {
+				_tmp6 = TRUE;
+			} else {
+				_tmp6 = !first;
+			}
+			/* first parameter is instance pointer in virtual methods, ignore*/
+			if (_tmp6) {
+				gee_collection_add ((GeeCollection*) parameters, param);
 			} else {
 				first = FALSE;
 			}
@@ -1811,15 +1789,48 @@ static ValaMethod* vala_gir_parser_parse_vmethod (ValaGirParser* self) {
 		}
 		vala_gir_parser_end_element (self, "parameters");
 	}
-	if (_vala_strcmp0 (throws_string, "1") == 0) {
-		ValaErrorType* _tmp6;
-		_tmp6 = NULL;
-		vala_code_node_add_error_type ((ValaCodeNode*) m, (ValaDataType*) (_tmp6 = vala_error_type_new (NULL, NULL, NULL)));
-		(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL));
+	i = 0;
+	if (_vala_strcmp0 (element_name, "method") == 0) {
+		/* implicit instance parameter*/
+		i++;
 	}
-	vala_gir_parser_end_element (self, "callback");
-	_tmp7 = NULL;
-	return (_tmp7 = m, name = (g_free (name), NULL), throws_string = (g_free (throws_string), NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), _tmp7);
+	{
+		GeeIterator* _param_it;
+		_param_it = gee_iterable_iterator ((GeeIterable*) parameters);
+		while (gee_iterator_next (_param_it)) {
+			ValaFormalParameter* param;
+			gboolean _tmp7;
+			gboolean _tmp8;
+			param = (ValaFormalParameter*) gee_iterator_get (_param_it);
+			_tmp7 = FALSE;
+			_tmp8 = FALSE;
+			if (!gee_collection_contains ((GeeCollection*) array_length_parameters, GINT_TO_POINTER (i))) {
+				_tmp8 = !gee_collection_contains ((GeeCollection*) closure_parameters, GINT_TO_POINTER (i));
+			} else {
+				_tmp8 = FALSE;
+			}
+			if (_tmp8) {
+				_tmp7 = !gee_collection_contains ((GeeCollection*) destroy_parameters, GINT_TO_POINTER (i));
+			} else {
+				_tmp7 = FALSE;
+			}
+			if (_tmp7) {
+				vala_method_add_parameter (m, param);
+			}
+			i++;
+			(param == NULL) ? NULL : (param = (vala_code_node_unref (param), NULL));
+		}
+		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
+	}
+	if (_vala_strcmp0 (throws_string, "1") == 0) {
+		ValaErrorType* _tmp9;
+		_tmp9 = NULL;
+		vala_code_node_add_error_type ((ValaCodeNode*) m, (ValaDataType*) (_tmp9 = vala_error_type_new (NULL, NULL, NULL)));
+		(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_code_node_unref (_tmp9), NULL));
+	}
+	vala_gir_parser_end_element (self, element_name);
+	_tmp10 = NULL;
+	return (_tmp10 = m, name = (g_free (name), NULL), throws_string = (g_free (throws_string), NULL), (return_type == NULL) ? NULL : (return_type = (vala_code_node_unref (return_type), NULL)), (parameters == NULL) ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL)), (array_length_parameters == NULL) ? NULL : (array_length_parameters = (gee_collection_object_unref (array_length_parameters), NULL)), (closure_parameters == NULL) ? NULL : (closure_parameters = (gee_collection_object_unref (closure_parameters), NULL)), (destroy_parameters == NULL) ? NULL : (destroy_parameters = (gee_collection_object_unref (destroy_parameters), NULL)), _tmp10);
 }
 
 
@@ -1873,7 +1884,7 @@ static ValaSignal* vala_gir_parser_parse_signal (ValaGirParser* self) {
 		while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 			ValaFormalParameter* _tmp8;
 			_tmp8 = NULL;
-			vala_signal_add_parameter (sig, _tmp8 = vala_gir_parser_parse_parameter (self, NULL));
+			vala_signal_add_parameter (sig, _tmp8 = vala_gir_parser_parse_parameter (self, NULL, NULL, NULL));
 			(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_code_node_unref (_tmp8), NULL));
 		}
 		vala_gir_parser_end_element (self, "parameters");
@@ -1888,12 +1899,18 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self) {
 	char* _tmp0;
 	ValaStruct* _tmp1;
 	ValaStruct* st;
+	char* cname;
+	ValaStruct* _tmp7;
 	g_return_val_if_fail (self != NULL, NULL);
 	vala_gir_parser_start_element (self, "glib:boxed");
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	st = (_tmp1 = vala_struct_new (_tmp0 = vala_markup_reader_get_attribute (self->priv->reader, "glib:name"), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 	vala_symbol_set_access ((ValaSymbol*) st, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	cname = vala_markup_reader_get_attribute (self->priv->reader, "c:type");
+	if (cname != NULL) {
+		vala_struct_set_cname (st, cname);
+	}
 	vala_gir_parser_next (self);
 	while (self->priv->current_token == VALA_MARKUP_TOKEN_TYPE_START_ELEMENT) {
 		if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "field") == 0) {
@@ -1911,7 +1928,7 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self) {
 				if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 					ValaMethod* _tmp4;
 					_tmp4 = NULL;
-					vala_struct_add_method (st, _tmp4 = vala_gir_parser_parse_method (self));
+					vala_struct_add_method (st, _tmp4 = vala_gir_parser_parse_method (self, "method"));
 					(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL));
 				} else {
 					char* _tmp6;
@@ -1928,7 +1945,8 @@ static ValaStruct* vala_gir_parser_parse_boxed (ValaGirParser* self) {
 		}
 	}
 	vala_gir_parser_end_element (self, "glib:boxed");
-	return st;
+	_tmp7 = NULL;
+	return (_tmp7 = st, cname = (g_free (cname), NULL), _tmp7);
 }
 
 
@@ -1959,7 +1977,7 @@ static ValaStruct* vala_gir_parser_parse_union (ValaGirParser* self) {
 				if (_vala_strcmp0 (vala_markup_reader_get_name (self->priv->reader), "method") == 0) {
 					ValaMethod* _tmp4;
 					_tmp4 = NULL;
-					vala_struct_add_method (st, _tmp4 = vala_gir_parser_parse_method (self));
+					vala_struct_add_method (st, _tmp4 = vala_gir_parser_parse_method (self, "method"));
 					(_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL));
 				} else {
 					char* _tmp6;
